# Julia API client for MatterMost

### Note about the openapi.json file

The original openapi.json file is not directly compatible with the julia-client generator. The following changes were made to the file:
- The tags with "ldap" or "LDAP" strings were unified into "LDAP"
- The `_` character was used once as a field `name` resulting in unamed keyword argument in the Julia code. This has been fixed by replacing the `_` with `update_time`. The change was made according to the description of the item.

The modified `.json` file can be found at `/openapi/openapi-v4.0.0-FIXED.json` and the original file can be found at `/openapi/openapi-v4.0.0.json`.

## Overview
This API client was generated by the [OpenAPI Generator](https://openapi-generator.tech) project.  By using the [openapi-spec](https://openapis.org) from a remote server, you can easily generate an API client.

- API version: 4.0.0
- Build package: org.openapitools.codegen.languages.JuliaClientCodegen


## Installation
Place the Julia files generated under the `src` folder in your Julia project. Include MatterMost.jl in the project code.
It would include the module named MatterMost.

Documentation is generated as markdown files under the `docs` folder. You can include them in your project documentation.
Documentation is also embedded in Julia which can be used with a Julia specific documentation generator.

## API Endpoints

Class | Method
------------ | -------------
*AuthenticationApi* | [**migrate_auth_to_ldap**](docs/AuthenticationApi.md#migrate_auth_to_ldap)<br/>**POST** /users/migrate_auth/ldap<br/>Migrate user accounts authentication type to LDAP.
*AuthenticationApi* | [**migrate_auth_to_saml**](docs/AuthenticationApi.md#migrate_auth_to_saml)<br/>**POST** /users/migrate_auth/saml<br/>Migrate user accounts authentication type to SAML.
*BleveApi* | [**purge_bleve_indexes**](docs/BleveApi.md#purge_bleve_indexes)<br/>**POST** /bleve/purge_indexes<br/>Purge all Bleve indexes
*BotsApi* | [**assign_bot**](docs/BotsApi.md#assign_bot)<br/>**POST** /bots/{bot_user_id}/assign/{user_id}<br/>Assign a bot to a user
*BotsApi* | [**convert_bot_to_user**](docs/BotsApi.md#convert_bot_to_user)<br/>**POST** /bots/{bot_user_id}/convert_to_user<br/>Convert a bot into a user
*BotsApi* | [**convert_user_to_bot**](docs/BotsApi.md#convert_user_to_bot)<br/>**POST** /users/{user_id}/convert_to_bot<br/>Convert a user into a bot
*BotsApi* | [**create_bot**](docs/BotsApi.md#create_bot)<br/>**POST** /bots<br/>Create a bot
*BotsApi* | [**delete_bot_icon_image**](docs/BotsApi.md#delete_bot_icon_image)<br/>**DELETE** /bots/{bot_user_id}/icon<br/>Delete bot&#39;s LHS icon image
*BotsApi* | [**disable_bot**](docs/BotsApi.md#disable_bot)<br/>**POST** /bots/{bot_user_id}/disable<br/>Disable a bot
*BotsApi* | [**enable_bot**](docs/BotsApi.md#enable_bot)<br/>**POST** /bots/{bot_user_id}/enable<br/>Enable a bot
*BotsApi* | [**get_bot**](docs/BotsApi.md#get_bot)<br/>**GET** /bots/{bot_user_id}<br/>Get a bot
*BotsApi* | [**get_bot_icon_image**](docs/BotsApi.md#get_bot_icon_image)<br/>**GET** /bots/{bot_user_id}/icon<br/>Get bot&#39;s LHS icon
*BotsApi* | [**get_bots**](docs/BotsApi.md#get_bots)<br/>**GET** /bots<br/>Get bots
*BotsApi* | [**patch_bot**](docs/BotsApi.md#patch_bot)<br/>**PUT** /bots/{bot_user_id}<br/>Patch a bot
*BotsApi* | [**set_bot_icon_image**](docs/BotsApi.md#set_bot_icon_image)<br/>**POST** /bots/{bot_user_id}/icon<br/>Set bot&#39;s LHS icon image
*BrandApi* | [**delete_brand_image**](docs/BrandApi.md#delete_brand_image)<br/>**DELETE** /brand/image<br/>Delete current brand image
*BrandApi* | [**get_brand_image**](docs/BrandApi.md#get_brand_image)<br/>**GET** /brand/image<br/>Get brand image
*BrandApi* | [**upload_brand_image**](docs/BrandApi.md#upload_brand_image)<br/>**POST** /brand/image<br/>Upload brand image
*ChannelsApi* | [**add_channel_member**](docs/ChannelsApi.md#add_channel_member)<br/>**POST** /channels/{channel_id}/members<br/>Add user to channel
*ChannelsApi* | [**autocomplete_channels_for_team**](docs/ChannelsApi.md#autocomplete_channels_for_team)<br/>**GET** /teams/{team_id}/channels/autocomplete<br/>Autocomplete channels
*ChannelsApi* | [**autocomplete_channels_for_team_for_search**](docs/ChannelsApi.md#autocomplete_channels_for_team_for_search)<br/>**GET** /teams/{team_id}/channels/search_autocomplete<br/>Autocomplete channels for search
*ChannelsApi* | [**channel_members_minus_group_members**](docs/ChannelsApi.md#channel_members_minus_group_members)<br/>**GET** /channels/{channel_id}/members_minus_group_members<br/>Channel members minus group members.
*ChannelsApi* | [**create_channel**](docs/ChannelsApi.md#create_channel)<br/>**POST** /channels<br/>Create a channel
*ChannelsApi* | [**create_direct_channel**](docs/ChannelsApi.md#create_direct_channel)<br/>**POST** /channels/direct<br/>Create a direct message channel
*ChannelsApi* | [**create_group_channel**](docs/ChannelsApi.md#create_group_channel)<br/>**POST** /channels/group<br/>Create a group message channel
*ChannelsApi* | [**create_sidebar_category_for_team_for_user**](docs/ChannelsApi.md#create_sidebar_category_for_team_for_user)<br/>**POST** /users/{user_id}/teams/{team_id}/channels/categories<br/>Create user&#39;s sidebar category
*ChannelsApi* | [**delete_channel**](docs/ChannelsApi.md#delete_channel)<br/>**DELETE** /channels/{channel_id}<br/>Delete a channel
*ChannelsApi* | [**get_all_channels**](docs/ChannelsApi.md#get_all_channels)<br/>**GET** /channels<br/>Get a list of all channels
*ChannelsApi* | [**get_channel**](docs/ChannelsApi.md#get_channel)<br/>**GET** /channels/{channel_id}<br/>Get a channel
*ChannelsApi* | [**get_channel_by_name**](docs/ChannelsApi.md#get_channel_by_name)<br/>**GET** /teams/{team_id}/channels/name/{channel_name}<br/>Get a channel by name
*ChannelsApi* | [**get_channel_by_name_for_team_name**](docs/ChannelsApi.md#get_channel_by_name_for_team_name)<br/>**GET** /teams/name/{team_name}/channels/name/{channel_name}<br/>Get a channel by name and team name
*ChannelsApi* | [**get_channel_member**](docs/ChannelsApi.md#get_channel_member)<br/>**GET** /channels/{channel_id}/members/{user_id}<br/>Get channel member
*ChannelsApi* | [**get_channel_member_counts_by_group**](docs/ChannelsApi.md#get_channel_member_counts_by_group)<br/>**GET** /channels/{channel_id}/member_counts_by_group<br/>Channel members counts for each group that has atleast one member in the channel
*ChannelsApi* | [**get_channel_members**](docs/ChannelsApi.md#get_channel_members)<br/>**GET** /channels/{channel_id}/members<br/>Get channel members
*ChannelsApi* | [**get_channel_members_by_ids**](docs/ChannelsApi.md#get_channel_members_by_ids)<br/>**POST** /channels/{channel_id}/members/ids<br/>Get channel members by ids
*ChannelsApi* | [**get_channel_members_for_user**](docs/ChannelsApi.md#get_channel_members_for_user)<br/>**GET** /users/{user_id}/teams/{team_id}/channels/members<br/>Get channel memberships and roles for a user
*ChannelsApi* | [**get_channel_members_timezones**](docs/ChannelsApi.md#get_channel_members_timezones)<br/>**GET** /channels/{channel_id}/timezones<br/>Get timezones in a channel
*ChannelsApi* | [**get_channel_moderations**](docs/ChannelsApi.md#get_channel_moderations)<br/>**GET** /channels/{channel_id}/moderations<br/>Get information about channel&#39;s moderation.
*ChannelsApi* | [**get_channel_stats**](docs/ChannelsApi.md#get_channel_stats)<br/>**GET** /channels/{channel_id}/stats<br/>Get channel statistics
*ChannelsApi* | [**get_channel_unread**](docs/ChannelsApi.md#get_channel_unread)<br/>**GET** /users/{user_id}/channels/{channel_id}/unread<br/>Get unread messages
*ChannelsApi* | [**get_channels_for_team_for_user**](docs/ChannelsApi.md#get_channels_for_team_for_user)<br/>**GET** /users/{user_id}/teams/{team_id}/channels<br/>Get channels for user
*ChannelsApi* | [**get_channels_for_user**](docs/ChannelsApi.md#get_channels_for_user)<br/>**GET** /users/{user_id}/channels<br/>Get all channels from all teams
*ChannelsApi* | [**get_deleted_channels_for_team**](docs/ChannelsApi.md#get_deleted_channels_for_team)<br/>**GET** /teams/{team_id}/channels/deleted<br/>Get deleted channels
*ChannelsApi* | [**get_pinned_posts**](docs/ChannelsApi.md#get_pinned_posts)<br/>**GET** /channels/{channel_id}/pinned<br/>Get a channel&#39;s pinned posts
*ChannelsApi* | [**get_private_channels_for_team**](docs/ChannelsApi.md#get_private_channels_for_team)<br/>**GET** /teams/{team_id}/channels/private<br/>Get private channels
*ChannelsApi* | [**get_public_channels_by_ids_for_team**](docs/ChannelsApi.md#get_public_channels_by_ids_for_team)<br/>**POST** /teams/{team_id}/channels/ids<br/>Get a list of channels by ids
*ChannelsApi* | [**get_public_channels_for_team**](docs/ChannelsApi.md#get_public_channels_for_team)<br/>**GET** /teams/{team_id}/channels<br/>Get public channels
*ChannelsApi* | [**get_sidebar_categories_for_team_for_user**](docs/ChannelsApi.md#get_sidebar_categories_for_team_for_user)<br/>**GET** /users/{user_id}/teams/{team_id}/channels/categories<br/>Get user&#39;s sidebar categories
*ChannelsApi* | [**get_sidebar_category_for_team_for_user**](docs/ChannelsApi.md#get_sidebar_category_for_team_for_user)<br/>**GET** /users/{user_id}/teams/{team_id}/channels/categories/{category_id}<br/>Get sidebar category
*ChannelsApi* | [**get_sidebar_category_order_for_team_for_user**](docs/ChannelsApi.md#get_sidebar_category_order_for_team_for_user)<br/>**GET** /users/{user_id}/teams/{team_id}/channels/categories/order<br/>Get user&#39;s sidebar category order
*ChannelsApi* | [**move_channel**](docs/ChannelsApi.md#move_channel)<br/>**POST** /channels/{channel_id}/move<br/>Move a channel
*ChannelsApi* | [**patch_channel**](docs/ChannelsApi.md#patch_channel)<br/>**PUT** /channels/{channel_id}/patch<br/>Patch a channel
*ChannelsApi* | [**patch_channel_moderations**](docs/ChannelsApi.md#patch_channel_moderations)<br/>**PUT** /channels/{channel_id}/moderations/patch<br/>Update a channel&#39;s moderation settings.
*ChannelsApi* | [**remove_sidebar_category_for_team_for_user**](docs/ChannelsApi.md#remove_sidebar_category_for_team_for_user)<br/>**DELETE** /users/{user_id}/teams/{team_id}/channels/categories/{category_id}<br/>Delete sidebar category
*ChannelsApi* | [**remove_user_from_channel**](docs/ChannelsApi.md#remove_user_from_channel)<br/>**DELETE** /channels/{channel_id}/members/{user_id}<br/>Remove user from channel
*ChannelsApi* | [**restore_channel**](docs/ChannelsApi.md#restore_channel)<br/>**POST** /channels/{channel_id}/restore<br/>Restore a channel
*ChannelsApi* | [**search_all_channels**](docs/ChannelsApi.md#search_all_channels)<br/>**POST** /channels/search<br/>Search all private and open type channels across all teams
*ChannelsApi* | [**search_archived_channels**](docs/ChannelsApi.md#search_archived_channels)<br/>**POST** /teams/{team_id}/channels/search_archived<br/>Search archived channels
*ChannelsApi* | [**search_channels**](docs/ChannelsApi.md#search_channels)<br/>**POST** /teams/{team_id}/channels/search<br/>Search channels
*ChannelsApi* | [**search_group_channels**](docs/ChannelsApi.md#search_group_channels)<br/>**POST** /channels/group/search<br/>Search Group Channels
*ChannelsApi* | [**update_channel**](docs/ChannelsApi.md#update_channel)<br/>**PUT** /channels/{channel_id}<br/>Update a channel
*ChannelsApi* | [**update_channel_member_scheme_roles**](docs/ChannelsApi.md#update_channel_member_scheme_roles)<br/>**PUT** /channels/{channel_id}/members/{user_id}/schemeRoles<br/>Update the scheme-derived roles of a channel member.
*ChannelsApi* | [**update_channel_notify_props**](docs/ChannelsApi.md#update_channel_notify_props)<br/>**PUT** /channels/{channel_id}/members/{user_id}/notify_props<br/>Update channel notifications
*ChannelsApi* | [**update_channel_privacy**](docs/ChannelsApi.md#update_channel_privacy)<br/>**PUT** /channels/{channel_id}/privacy<br/>Update channel&#39;s privacy
*ChannelsApi* | [**update_channel_roles**](docs/ChannelsApi.md#update_channel_roles)<br/>**PUT** /channels/{channel_id}/members/{user_id}/roles<br/>Update channel roles
*ChannelsApi* | [**update_channel_scheme**](docs/ChannelsApi.md#update_channel_scheme)<br/>**PUT** /channels/{channel_id}/scheme<br/>Set a channel&#39;s scheme
*ChannelsApi* | [**update_sidebar_categories_for_team_for_user**](docs/ChannelsApi.md#update_sidebar_categories_for_team_for_user)<br/>**PUT** /users/{user_id}/teams/{team_id}/channels/categories<br/>Update user&#39;s sidebar categories
*ChannelsApi* | [**update_sidebar_category_for_team_for_user**](docs/ChannelsApi.md#update_sidebar_category_for_team_for_user)<br/>**PUT** /users/{user_id}/teams/{team_id}/channels/categories/{category_id}<br/>Update sidebar category
*ChannelsApi* | [**update_sidebar_category_order_for_team_for_user**](docs/ChannelsApi.md#update_sidebar_category_order_for_team_for_user)<br/>**PUT** /users/{user_id}/teams/{team_id}/channels/categories/order<br/>Update user&#39;s sidebar category order
*ChannelsApi* | [**view_channel**](docs/ChannelsApi.md#view_channel)<br/>**POST** /channels/members/{user_id}/view<br/>View channel
*CloudApi* | [**confirm_customer_payment**](docs/CloudApi.md#confirm_customer_payment)<br/>**POST** /cloud/payment/confirm<br/>Completes the payment setup intent
*CloudApi* | [**create_customer_payment**](docs/CloudApi.md#create_customer_payment)<br/>**POST** /cloud/payment<br/>Create a customer setup payment intent
*CloudApi* | [**get_cloud_customer**](docs/CloudApi.md#get_cloud_customer)<br/>**GET** /cloud/customer<br/>Get cloud customer
*CloudApi* | [**get_cloud_limits**](docs/CloudApi.md#get_cloud_limits)<br/>**GET** /cloud/limits<br/>Get cloud workspace limits
*CloudApi* | [**get_cloud_products**](docs/CloudApi.md#get_cloud_products)<br/>**GET** /cloud/products<br/>Get cloud products
*CloudApi* | [**get_invoice_for_subscription_as_pdf**](docs/CloudApi.md#get_invoice_for_subscription_as_pdf)<br/>**GET** /cloud/subscription/invoices/{invoice_id}/pdf<br/>Get cloud invoice PDF
*CloudApi* | [**get_invoices_for_subscription**](docs/CloudApi.md#get_invoices_for_subscription)<br/>**GET** /cloud/subscription/invoices<br/>Get cloud subscription invoices
*CloudApi* | [**get_subscription**](docs/CloudApi.md#get_subscription)<br/>**GET** /cloud/subscription<br/>Get cloud subscription
*CloudApi* | [**post_endpoint_for_cws_webhooks**](docs/CloudApi.md#post_endpoint_for_cws_webhooks)<br/>**POST** /cloud/webhook<br/>POST endpoint for CWS Webhooks
*CloudApi* | [**update_cloud_customer**](docs/CloudApi.md#update_cloud_customer)<br/>**PUT** /cloud/customer<br/>Update cloud customer
*CloudApi* | [**update_cloud_customer_address**](docs/CloudApi.md#update_cloud_customer_address)<br/>**PUT** /cloud/customer/address<br/>Update cloud customer address
*ClusterApi* | [**get_cluster_status**](docs/ClusterApi.md#get_cluster_status)<br/>**GET** /cluster/status<br/>Get cluster status
*CommandsApi* | [**create_command**](docs/CommandsApi.md#create_command)<br/>**POST** /commands<br/>Create a command
*CommandsApi* | [**delete_command**](docs/CommandsApi.md#delete_command)<br/>**DELETE** /commands/{command_id}<br/>Delete a command
*CommandsApi* | [**execute_command**](docs/CommandsApi.md#execute_command)<br/>**POST** /commands/execute<br/>Execute a command
*CommandsApi* | [**get_command_by_id**](docs/CommandsApi.md#get_command_by_id)<br/>**GET** /commands/{command_id}<br/>Get a command
*CommandsApi* | [**list_autocomplete_commands**](docs/CommandsApi.md#list_autocomplete_commands)<br/>**GET** /teams/{team_id}/commands/autocomplete<br/>List autocomplete commands
*CommandsApi* | [**list_command_autocomplete_suggestions**](docs/CommandsApi.md#list_command_autocomplete_suggestions)<br/>**GET** /teams/{team_id}/commands/autocomplete_suggestions<br/>List commands&#39; autocomplete data
*CommandsApi* | [**list_commands**](docs/CommandsApi.md#list_commands)<br/>**GET** /commands<br/>List commands for a team
*CommandsApi* | [**move_command**](docs/CommandsApi.md#move_command)<br/>**PUT** /commands/{command_id}/move<br/>Move a command
*CommandsApi* | [**regen_command_token**](docs/CommandsApi.md#regen_command_token)<br/>**PUT** /commands/{command_id}/regen_token<br/>Generate a new token
*CommandsApi* | [**update_command**](docs/CommandsApi.md#update_command)<br/>**PUT** /commands/{command_id}<br/>Update a command
*ComplianceApi* | [**create_compliance_report**](docs/ComplianceApi.md#create_compliance_report)<br/>**POST** /compliance/reports<br/>Create report
*ComplianceApi* | [**download_compliance_report**](docs/ComplianceApi.md#download_compliance_report)<br/>**GET** /compliance/reports/{report_id}/download<br/>Download a report
*ComplianceApi* | [**get_compliance_report**](docs/ComplianceApi.md#get_compliance_report)<br/>**GET** /compliance/reports/{report_id}<br/>Get a report
*ComplianceApi* | [**get_compliance_reports**](docs/ComplianceApi.md#get_compliance_reports)<br/>**GET** /compliance/reports<br/>Get reports
*DataRetentionApi* | [**add_channels_to_retention_policy**](docs/DataRetentionApi.md#add_channels_to_retention_policy)<br/>**POST** /data_retention/policies/{policy_id}/channels<br/>Add channels to a granular data retention policy
*DataRetentionApi* | [**add_teams_to_retention_policy**](docs/DataRetentionApi.md#add_teams_to_retention_policy)<br/>**POST** /data_retention/policies/{policy_id}/teams<br/>Add teams to a granular data retention policy
*DataRetentionApi* | [**create_data_retention_policy**](docs/DataRetentionApi.md#create_data_retention_policy)<br/>**POST** /data_retention/policies<br/>Create a new granular data retention policy
*DataRetentionApi* | [**delete_data_retention_policy**](docs/DataRetentionApi.md#delete_data_retention_policy)<br/>**DELETE** /data_retention/policies/{policy_id}<br/>Delete a granular data retention policy
*DataRetentionApi* | [**get_channel_policies_for_user**](docs/DataRetentionApi.md#get_channel_policies_for_user)<br/>**GET** /users/{user_id}/data_retention/channel_policies<br/>Get the policies which are applied to a user&#39;s channels
*DataRetentionApi* | [**get_channels_for_retention_policy**](docs/DataRetentionApi.md#get_channels_for_retention_policy)<br/>**GET** /data_retention/policies/{policy_id}/channels<br/>Get the channels for a granular data retention policy
*DataRetentionApi* | [**get_data_retention_policies**](docs/DataRetentionApi.md#get_data_retention_policies)<br/>**GET** /data_retention/policies<br/>Get the granular data retention policies
*DataRetentionApi* | [**get_data_retention_policies_count**](docs/DataRetentionApi.md#get_data_retention_policies_count)<br/>**GET** /data_retention/policies_count<br/>Get the number of granular data retention policies
*DataRetentionApi* | [**get_data_retention_policy**](docs/DataRetentionApi.md#get_data_retention_policy)<br/>**GET** /data_retention/policy<br/>Get the global data retention policy
*DataRetentionApi* | [**get_data_retention_policy_by_i_d**](docs/DataRetentionApi.md#get_data_retention_policy_by_i_d)<br/>**GET** /data_retention/policies/{policy_id}<br/>Get a granular data retention policy
*DataRetentionApi* | [**get_team_policies_for_user**](docs/DataRetentionApi.md#get_team_policies_for_user)<br/>**GET** /users/{user_id}/data_retention/team_policies<br/>Get the policies which are applied to a user&#39;s teams
*DataRetentionApi* | [**get_teams_for_retention_policy**](docs/DataRetentionApi.md#get_teams_for_retention_policy)<br/>**GET** /data_retention/policies/{policy_id}/teams<br/>Get the teams for a granular data retention policy
*DataRetentionApi* | [**patch_data_retention_policy**](docs/DataRetentionApi.md#patch_data_retention_policy)<br/>**PATCH** /data_retention/policies/{policy_id}<br/>Patch a granular data retention policy
*DataRetentionApi* | [**remove_channels_from_retention_policy**](docs/DataRetentionApi.md#remove_channels_from_retention_policy)<br/>**DELETE** /data_retention/policies/{policy_id}/channels<br/>Delete channels from a granular data retention policy
*DataRetentionApi* | [**remove_teams_from_retention_policy**](docs/DataRetentionApi.md#remove_teams_from_retention_policy)<br/>**DELETE** /data_retention/policies/{policy_id}/teams<br/>Delete teams from a granular data retention policy
*DataRetentionApi* | [**search_channels_for_retention_policy**](docs/DataRetentionApi.md#search_channels_for_retention_policy)<br/>**POST** /data_retention/policies/{policy_id}/channels/search<br/>Search for the channels in a granular data retention policy
*DataRetentionApi* | [**search_teams_for_retention_policy**](docs/DataRetentionApi.md#search_teams_for_retention_policy)<br/>**POST** /data_retention/policies/{policy_id}/teams/search<br/>Search for the teams in a granular data retention policy
*ElasticsearchApi* | [**purge_elasticsearch_indexes**](docs/ElasticsearchApi.md#purge_elasticsearch_indexes)<br/>**POST** /elasticsearch/purge_indexes<br/>Purge all Elasticsearch indexes
*ElasticsearchApi* | [**test_elasticsearch**](docs/ElasticsearchApi.md#test_elasticsearch)<br/>**POST** /elasticsearch/test<br/>Test Elasticsearch configuration
*EmojiApi* | [**autocomplete_emoji**](docs/EmojiApi.md#autocomplete_emoji)<br/>**GET** /emoji/autocomplete<br/>Autocomplete custom emoji
*EmojiApi* | [**create_emoji**](docs/EmojiApi.md#create_emoji)<br/>**POST** /emoji<br/>Create a custom emoji
*EmojiApi* | [**delete_emoji**](docs/EmojiApi.md#delete_emoji)<br/>**DELETE** /emoji/{emoji_id}<br/>Delete a custom emoji
*EmojiApi* | [**get_emoji**](docs/EmojiApi.md#get_emoji)<br/>**GET** /emoji/{emoji_id}<br/>Get a custom emoji
*EmojiApi* | [**get_emoji_by_name**](docs/EmojiApi.md#get_emoji_by_name)<br/>**GET** /emoji/name/{emoji_name}<br/>Get a custom emoji by name
*EmojiApi* | [**get_emoji_image**](docs/EmojiApi.md#get_emoji_image)<br/>**GET** /emoji/{emoji_id}/image<br/>Get custom emoji image
*EmojiApi* | [**get_emoji_list**](docs/EmojiApi.md#get_emoji_list)<br/>**GET** /emoji<br/>Get a list of custom emoji
*EmojiApi* | [**search_emoji**](docs/EmojiApi.md#search_emoji)<br/>**POST** /emoji/search<br/>Search custom emoji
*ExportsApi* | [**delete_export**](docs/ExportsApi.md#delete_export)<br/>**DELETE** /exports/{export_name}<br/>Delete an export file
*ExportsApi* | [**download_export**](docs/ExportsApi.md#download_export)<br/>**GET** /exports/{export_name}<br/>Download an export file
*ExportsApi* | [**list_exports**](docs/ExportsApi.md#list_exports)<br/>**GET** /exports<br/>List export files
*FilesApi* | [**get_file**](docs/FilesApi.md#get_file)<br/>**GET** /files/{file_id}<br/>Get a file
*FilesApi* | [**get_file_info**](docs/FilesApi.md#get_file_info)<br/>**GET** /files/{file_id}/info<br/>Get metadata for a file
*FilesApi* | [**get_file_link**](docs/FilesApi.md#get_file_link)<br/>**GET** /files/{file_id}/link<br/>Get a public file link
*FilesApi* | [**get_file_preview**](docs/FilesApi.md#get_file_preview)<br/>**GET** /files/{file_id}/preview<br/>Get a file&#39;s preview
*FilesApi* | [**get_file_public**](docs/FilesApi.md#get_file_public)<br/>**GET** /files/{file_id}/public<br/>Get a public file
*FilesApi* | [**get_file_thumbnail**](docs/FilesApi.md#get_file_thumbnail)<br/>**GET** /files/{file_id}/thumbnail<br/>Get a file&#39;s thumbnail
*FilesApi* | [**search_files**](docs/FilesApi.md#search_files)<br/>**POST** /teams/{team_id}/files/search<br/>Search files in a team
*FilesApi* | [**upload_file**](docs/FilesApi.md#upload_file)<br/>**POST** /files<br/>Upload a file
*GroupsApi* | [**add_group_members**](docs/GroupsApi.md#add_group_members)<br/>**POST** /groups/{group_id}/members<br/>Adds members to a custom group
*GroupsApi* | [**create_group**](docs/GroupsApi.md#create_group)<br/>**POST** /groups<br/>Create a custom group
*GroupsApi* | [**delete_group**](docs/GroupsApi.md#delete_group)<br/>**DELETE** /groups/{group_id}<br/>Deletes a custom group
*GroupsApi* | [**delete_group_members**](docs/GroupsApi.md#delete_group_members)<br/>**DELETE** /groups/{group_id}/members<br/>Removes members from a custom group
*GroupsApi* | [**get_group**](docs/GroupsApi.md#get_group)<br/>**GET** /groups/{group_id}<br/>Get a group
*GroupsApi* | [**get_group_stats**](docs/GroupsApi.md#get_group_stats)<br/>**GET** /groups/{group_id}/stats<br/>Get group stats
*GroupsApi* | [**get_group_syncable_for_channel_id**](docs/GroupsApi.md#get_group_syncable_for_channel_id)<br/>**GET** /groups/{group_id}/channels/{channel_id}<br/>Get GroupSyncable from channel ID
*GroupsApi* | [**get_group_syncable_for_team_id**](docs/GroupsApi.md#get_group_syncable_for_team_id)<br/>**GET** /groups/{group_id}/teams/{team_id}<br/>Get GroupSyncable from Team ID
*GroupsApi* | [**get_group_syncables_channels**](docs/GroupsApi.md#get_group_syncables_channels)<br/>**GET** /groups/{group_id}/channels<br/>Get group channels
*GroupsApi* | [**get_group_syncables_teams**](docs/GroupsApi.md#get_group_syncables_teams)<br/>**GET** /groups/{group_id}/teams<br/>Get group teams
*GroupsApi* | [**get_group_users**](docs/GroupsApi.md#get_group_users)<br/>**GET** /groups/{group_id}/members<br/>Get group users
*GroupsApi* | [**get_groups**](docs/GroupsApi.md#get_groups)<br/>**GET** /groups<br/>Get groups
*GroupsApi* | [**get_groups_associated_to_channels_by_team**](docs/GroupsApi.md#get_groups_associated_to_channels_by_team)<br/>**GET** /teams/{team_id}/groups_by_channels<br/>Get team groups by channels
*GroupsApi* | [**get_groups_by_channel**](docs/GroupsApi.md#get_groups_by_channel)<br/>**GET** /channels/{channel_id}/groups<br/>Get channel groups
*GroupsApi* | [**get_groups_by_team**](docs/GroupsApi.md#get_groups_by_team)<br/>**GET** /teams/{team_id}/groups<br/>Get team groups
*GroupsApi* | [**get_groups_by_user_id**](docs/GroupsApi.md#get_groups_by_user_id)<br/>**GET** /users/{user_id}/groups<br/>Get groups for a userId
*GroupsApi* | [**link_group_syncable_for_channel**](docs/GroupsApi.md#link_group_syncable_for_channel)<br/>**POST** /groups/{group_id}/channels/{channel_id}/link<br/>Link a channel to a group
*GroupsApi* | [**link_group_syncable_for_team**](docs/GroupsApi.md#link_group_syncable_for_team)<br/>**POST** /groups/{group_id}/teams/{team_id}/link<br/>Link a team to a group
*GroupsApi* | [**patch_group**](docs/GroupsApi.md#patch_group)<br/>**PUT** /groups/{group_id}/patch<br/>Patch a group
*GroupsApi* | [**patch_group_syncable_for_channel**](docs/GroupsApi.md#patch_group_syncable_for_channel)<br/>**PUT** /groups/{group_id}/channels/{channel_id}/patch<br/>Patch a GroupSyncable associated to Channel
*GroupsApi* | [**patch_group_syncable_for_team**](docs/GroupsApi.md#patch_group_syncable_for_team)<br/>**PUT** /groups/{group_id}/teams/{team_id}/patch<br/>Patch a GroupSyncable associated to Team
*GroupsApi* | [**unlink_group_syncable_for_channel**](docs/GroupsApi.md#unlink_group_syncable_for_channel)<br/>**DELETE** /groups/{group_id}/channels/{channel_id}/link<br/>Delete a link from a channel to a group
*GroupsApi* | [**unlink_group_syncable_for_team**](docs/GroupsApi.md#unlink_group_syncable_for_team)<br/>**DELETE** /groups/{group_id}/teams/{team_id}/link<br/>Delete a link from a team to a group
*GroupsApi* | [**unlink_ldap_group**](docs/GroupsApi.md#unlink_ldap_group)<br/>**DELETE** /ldap/groups/{remote_id}/link<br/>Delete a link for LDAP group
*ImportsApi* | [**list_imports**](docs/ImportsApi.md#list_imports)<br/>**GET** /imports<br/>List import files
*InsightsApi* | [**get_new_team_members**](docs/InsightsApi.md#get_new_team_members)<br/>**GET** /teams/{team_id}/top/team_members<br/>Get a list of new team members.
*InsightsApi* | [**get_top_channels_for_team**](docs/InsightsApi.md#get_top_channels_for_team)<br/>**GET** /teams/{team_id}/top/channels<br/>Get a list of the top channels for a team.
*InsightsApi* | [**get_top_channels_for_user**](docs/InsightsApi.md#get_top_channels_for_user)<br/>**GET** /users/me/top/channels<br/>Get a list of the top channels for a user.
*InsightsApi* | [**get_top_d_ms_for_user**](docs/InsightsApi.md#get_top_d_ms_for_user)<br/>**GET** /users/me/top/dms<br/>Get a list of the top dms for a user.
*InsightsApi* | [**get_top_reactions_for_team**](docs/InsightsApi.md#get_top_reactions_for_team)<br/>**GET** /teams/{team_id}/top/reactions<br/>Get a list of the top reactions for a team.
*InsightsApi* | [**get_top_reactions_for_user**](docs/InsightsApi.md#get_top_reactions_for_user)<br/>**GET** /users/me/top/reactions<br/>Get a list of the top reactions for a user.
*InsightsApi* | [**get_top_threads_for_team**](docs/InsightsApi.md#get_top_threads_for_team)<br/>**GET** /teams/{team_id}/top/threads<br/>Get a list of the top threads for a team.
*InsightsApi* | [**get_top_threads_for_user**](docs/InsightsApi.md#get_top_threads_for_user)<br/>**GET** /users/me/top/threads<br/>Get a list of the top threads for a user.
*IntegrationActionsApi* | [**open_interactive_dialog**](docs/IntegrationActionsApi.md#open_interactive_dialog)<br/>**POST** /actions/dialogs/open<br/>Open a dialog
*IntegrationActionsApi* | [**submit_interactive_dialog**](docs/IntegrationActionsApi.md#submit_interactive_dialog)<br/>**POST** /actions/dialogs/submit<br/>Submit a dialog
*InternalApi* | [**create_playbook_run_from_dialog**](docs/InternalApi.md#create_playbook_run_from_dialog)<br/>**POST** /runs/dialog<br/>Create a new playbook run from dialog
*InternalApi* | [**end_playbook_run_dialog**](docs/InternalApi.md#end_playbook_run_dialog)<br/>**POST** /runs/{id}/end<br/>End a playbook run from dialog
*InternalApi* | [**get_checklist_autocomplete**](docs/InternalApi.md#get_checklist_autocomplete)<br/>**GET** /runs/checklist-autocomplete<br/>Get autocomplete data for /playbook check
*InternalApi* | [**next_stage_dialog**](docs/InternalApi.md#next_stage_dialog)<br/>**POST** /runs/{id}/next-stage-dialog<br/>Go to next stage from dialog
*JobsApi* | [**cancel_job**](docs/JobsApi.md#cancel_job)<br/>**POST** /jobs/{job_id}/cancel<br/>Cancel a job.
*JobsApi* | [**create_job**](docs/JobsApi.md#create_job)<br/>**POST** /jobs<br/>Create a new job.
*JobsApi* | [**download_job**](docs/JobsApi.md#download_job)<br/>**GET** /jobs/{job_id}/download<br/>Download the results of a job.
*JobsApi* | [**get_job**](docs/JobsApi.md#get_job)<br/>**GET** /jobs/{job_id}<br/>Get a job.
*JobsApi* | [**get_jobs**](docs/JobsApi.md#get_jobs)<br/>**GET** /jobs<br/>Get the jobs.
*JobsApi* | [**get_jobs_by_type**](docs/JobsApi.md#get_jobs_by_type)<br/>**GET** /jobs/type/{type}<br/>Get the jobs of the given type.
*LDAPApi* | [**delete_ldap_private_certificate**](docs/LDAPApi.md#delete_ldap_private_certificate)<br/>**DELETE** /ldap/certificate/private<br/>Remove private key
*LDAPApi* | [**delete_ldap_public_certificate**](docs/LDAPApi.md#delete_ldap_public_certificate)<br/>**DELETE** /ldap/certificate/public<br/>Remove public certificate
*LDAPApi* | [**get_ldap_groups**](docs/LDAPApi.md#get_ldap_groups)<br/>**GET** /ldap/groups<br/>Returns a list of LDAP groups
*LDAPApi* | [**link_ldap_group**](docs/LDAPApi.md#link_ldap_group)<br/>**POST** /ldap/groups/{remote_id}/link<br/>Link a LDAP group
*LDAPApi* | [**migrate_auth_to_ldap**](docs/LDAPApi.md#migrate_auth_to_ldap)<br/>**POST** /users/migrate_auth/ldap<br/>Migrate user accounts authentication type to LDAP.
*LDAPApi* | [**migrate_id_ldap**](docs/LDAPApi.md#migrate_id_ldap)<br/>**POST** /ldap/migrateid<br/>Migrate Id LDAP
*LDAPApi* | [**sync_ldap**](docs/LDAPApi.md#sync_ldap)<br/>**POST** /ldap/sync<br/>Sync with LDAP
*LDAPApi* | [**test_ldap**](docs/LDAPApi.md#test_ldap)<br/>**POST** /ldap/test<br/>Test LDAP configuration
*LDAPApi* | [**upload_ldap_private_certificate**](docs/LDAPApi.md#upload_ldap_private_certificate)<br/>**POST** /ldap/certificate/private<br/>Upload private key
*LDAPApi* | [**upload_ldap_public_certificate**](docs/LDAPApi.md#upload_ldap_public_certificate)<br/>**POST** /ldap/certificate/public<br/>Upload public certificate
*MigrateApi* | [**migrate_auth_to_ldap**](docs/MigrateApi.md#migrate_auth_to_ldap)<br/>**POST** /users/migrate_auth/ldap<br/>Migrate user accounts authentication type to LDAP.
*MigrateApi* | [**migrate_auth_to_saml**](docs/MigrateApi.md#migrate_auth_to_saml)<br/>**POST** /users/migrate_auth/saml<br/>Migrate user accounts authentication type to SAML.
*OAuthApi* | [**create_o_auth_app**](docs/OAuthApi.md#create_o_auth_app)<br/>**POST** /oauth/apps<br/>Register OAuth app
*OAuthApi* | [**delete_o_auth_app**](docs/OAuthApi.md#delete_o_auth_app)<br/>**DELETE** /oauth/apps/{app_id}<br/>Delete an OAuth app
*OAuthApi* | [**get_authorized_o_auth_apps_for_user**](docs/OAuthApi.md#get_authorized_o_auth_apps_for_user)<br/>**GET** /users/{user_id}/oauth/apps/authorized<br/>Get authorized OAuth apps
*OAuthApi* | [**get_o_auth_app**](docs/OAuthApi.md#get_o_auth_app)<br/>**GET** /oauth/apps/{app_id}<br/>Get an OAuth app
*OAuthApi* | [**get_o_auth_app_info**](docs/OAuthApi.md#get_o_auth_app_info)<br/>**GET** /oauth/apps/{app_id}/info<br/>Get info on an OAuth app
*OAuthApi* | [**get_o_auth_apps**](docs/OAuthApi.md#get_o_auth_apps)<br/>**GET** /oauth/apps<br/>Get OAuth apps
*OAuthApi* | [**regenerate_o_auth_app_secret**](docs/OAuthApi.md#regenerate_o_auth_app_secret)<br/>**POST** /oauth/apps/{app_id}/regen_secret<br/>Regenerate OAuth app secret
*OAuthApi* | [**update_o_auth_app**](docs/OAuthApi.md#update_o_auth_app)<br/>**PUT** /oauth/apps/{app_id}<br/>Update an OAuth app
*OpenGraphApi* | [**open_graph**](docs/OpenGraphApi.md#open_graph)<br/>**POST** /opengraph<br/>Get open graph metadata for url
*PermissionsApi* | [**get_ancillary_permissions**](docs/PermissionsApi.md#get_ancillary_permissions)<br/>**GET** /permissions/ancillary<br/>Return all system console subsection ancillary permissions
*PlaybookAutofollowsApi* | [**get_auto_follows**](docs/PlaybookAutofollowsApi.md#get_auto_follows)<br/>**GET** /playbooks/{id}/autofollows<br/>Get the list of followers&#39; user IDs of a playbook
*PlaybookRunsApi* | [**add_checklist_item**](docs/PlaybookRunsApi.md#add_checklist_item)<br/>**PUT** /runs/{id}/checklists/{checklist}/add<br/>Add an item to a playbook run&#39;s checklist
*PlaybookRunsApi* | [**change_owner**](docs/PlaybookRunsApi.md#change_owner)<br/>**POST** /runs/{id}/owner<br/>Update playbook run owner
*PlaybookRunsApi* | [**create_playbook_run_from_post**](docs/PlaybookRunsApi.md#create_playbook_run_from_post)<br/>**POST** /runs<br/>Create a new playbook run
*PlaybookRunsApi* | [**end_playbook_run**](docs/PlaybookRunsApi.md#end_playbook_run)<br/>**PUT** /runs/{id}/end<br/>End a playbook run
*PlaybookRunsApi* | [**finish**](docs/PlaybookRunsApi.md#finish)<br/>**PUT** /runs/{id}/finish<br/>Finish a playbook
*PlaybookRunsApi* | [**get_channels**](docs/PlaybookRunsApi.md#get_channels)<br/>**GET** /runs/channels<br/>Get playbook run channels
*PlaybookRunsApi* | [**get_owners**](docs/PlaybookRunsApi.md#get_owners)<br/>**GET** /runs/owners<br/>Get all owners
*PlaybookRunsApi* | [**get_playbook_run**](docs/PlaybookRunsApi.md#get_playbook_run)<br/>**GET** /runs/{id}<br/>Get a playbook run
*PlaybookRunsApi* | [**get_playbook_run_by_channel_id**](docs/PlaybookRunsApi.md#get_playbook_run_by_channel_id)<br/>**GET** /runs/channel/{channel_id}<br/>Find playbook run by channel ID
*PlaybookRunsApi* | [**get_playbook_run_metadata**](docs/PlaybookRunsApi.md#get_playbook_run_metadata)<br/>**GET** /runs/{id}/metadata<br/>Get playbook run metadata
*PlaybookRunsApi* | [**item_delete**](docs/PlaybookRunsApi.md#item_delete)<br/>**DELETE** /runs/{id}/checklists/{checklist}/item/{item}<br/>Delete an item of a playbook run&#39;s checklist
*PlaybookRunsApi* | [**item_rename**](docs/PlaybookRunsApi.md#item_rename)<br/>**PUT** /runs/{id}/checklists/{checklist}/item/{item}<br/>Update an item of a playbook run&#39;s checklist
*PlaybookRunsApi* | [**item_run**](docs/PlaybookRunsApi.md#item_run)<br/>**PUT** /runs/{id}/checklists/{checklist}/item/{item}/run<br/>Run an item&#39;s slash command
*PlaybookRunsApi* | [**item_set_assignee**](docs/PlaybookRunsApi.md#item_set_assignee)<br/>**PUT** /runs/{id}/checklists/{checklist}/item/{item}/assignee<br/>Update the assignee of an item
*PlaybookRunsApi* | [**item_set_state**](docs/PlaybookRunsApi.md#item_set_state)<br/>**PUT** /runs/{id}/checklists/{checklist}/item/{item}/state<br/>Update the state of an item
*PlaybookRunsApi* | [**list_playbook_runs**](docs/PlaybookRunsApi.md#list_playbook_runs)<br/>**GET** /runs<br/>List all playbook runs
*PlaybookRunsApi* | [**reoder_checklist_item**](docs/PlaybookRunsApi.md#reoder_checklist_item)<br/>**PUT** /runs/{id}/checklists/{checklist}/reorder<br/>Reorder an item in a playbook run&#39;s checklist
*PlaybookRunsApi* | [**restart_playbook_run**](docs/PlaybookRunsApi.md#restart_playbook_run)<br/>**PUT** /runs/{id}/restart<br/>Restart a playbook run
*PlaybookRunsApi* | [**status**](docs/PlaybookRunsApi.md#status)<br/>**POST** /runs/{id}/status<br/>Update a playbook run&#39;s status
*PlaybookRunsApi* | [**update_playbook_run**](docs/PlaybookRunsApi.md#update_playbook_run)<br/>**PATCH** /runs/{id}<br/>Update a playbook run
*PlaybooksApi* | [**create_playbook**](docs/PlaybooksApi.md#create_playbook)<br/>**POST** /playbooks<br/>Create a playbook
*PlaybooksApi* | [**delete_playbook**](docs/PlaybooksApi.md#delete_playbook)<br/>**DELETE** /playbooks/{id}<br/>Delete a playbook
*PlaybooksApi* | [**get_playbook**](docs/PlaybooksApi.md#get_playbook)<br/>**GET** /playbooks/{id}<br/>Get a playbook
*PlaybooksApi* | [**get_playbooks**](docs/PlaybooksApi.md#get_playbooks)<br/>**GET** /playbooks<br/>List all playbooks
*PlaybooksApi* | [**update_playbook**](docs/PlaybooksApi.md#update_playbook)<br/>**PUT** /playbooks/{id}<br/>Update a playbook
*PluginsApi* | [**disable_plugin**](docs/PluginsApi.md#disable_plugin)<br/>**POST** /plugins/{plugin_id}/disable<br/>Disable plugin
*PluginsApi* | [**enable_plugin**](docs/PluginsApi.md#enable_plugin)<br/>**POST** /plugins/{plugin_id}/enable<br/>Enable plugin
*PluginsApi* | [**get_marketplace_plugins**](docs/PluginsApi.md#get_marketplace_plugins)<br/>**GET** /plugins/marketplace<br/>Gets all the marketplace plugins
*PluginsApi* | [**get_marketplace_visited_by_admin**](docs/PluginsApi.md#get_marketplace_visited_by_admin)<br/>**GET** /plugins/marketplace/first_admin_visit<br/>Get if the Plugin Marketplace has been visited by at least an admin.
*PluginsApi* | [**get_plugin_statuses**](docs/PluginsApi.md#get_plugin_statuses)<br/>**GET** /plugins/statuses<br/>Get plugins status
*PluginsApi* | [**get_plugins**](docs/PluginsApi.md#get_plugins)<br/>**GET** /plugins<br/>Get plugins
*PluginsApi* | [**get_webapp_plugins**](docs/PluginsApi.md#get_webapp_plugins)<br/>**GET** /plugins/webapp<br/>Get webapp plugins
*PluginsApi* | [**install_marketplace_plugin**](docs/PluginsApi.md#install_marketplace_plugin)<br/>**POST** /plugins/marketplace<br/>Installs a marketplace plugin
*PluginsApi* | [**install_plugin_from_url**](docs/PluginsApi.md#install_plugin_from_url)<br/>**POST** /plugins/install_from_url<br/>Install plugin from url
*PluginsApi* | [**remove_plugin**](docs/PluginsApi.md#remove_plugin)<br/>**DELETE** /plugins/{plugin_id}<br/>Remove plugin
*PluginsApi* | [**upload_plugin**](docs/PluginsApi.md#upload_plugin)<br/>**POST** /plugins<br/>Upload plugin
*PostsApi* | [**create_post**](docs/PostsApi.md#create_post)<br/>**POST** /posts<br/>Create a post
*PostsApi* | [**create_post_ephemeral**](docs/PostsApi.md#create_post_ephemeral)<br/>**POST** /posts/ephemeral<br/>Create a ephemeral post
*PostsApi* | [**delete_post**](docs/PostsApi.md#delete_post)<br/>**DELETE** /posts/{post_id}<br/>Delete a post
*PostsApi* | [**do_post_action**](docs/PostsApi.md#do_post_action)<br/>**POST** /posts/{post_id}/actions/{action_id}<br/>Perform a post action
*PostsApi* | [**get_file_infos_for_post**](docs/PostsApi.md#get_file_infos_for_post)<br/>**GET** /posts/{post_id}/files/info<br/>Get file info for post
*PostsApi* | [**get_flagged_posts_for_user**](docs/PostsApi.md#get_flagged_posts_for_user)<br/>**GET** /users/{user_id}/posts/flagged<br/>Get a list of flagged posts
*PostsApi* | [**get_post**](docs/PostsApi.md#get_post)<br/>**GET** /posts/{post_id}<br/>Get a post
*PostsApi* | [**get_post_thread**](docs/PostsApi.md#get_post_thread)<br/>**GET** /posts/{post_id}/thread<br/>Get a thread
*PostsApi* | [**get_posts_around_last_unread**](docs/PostsApi.md#get_posts_around_last_unread)<br/>**GET** /users/{user_id}/channels/{channel_id}/posts/unread<br/>Get posts around oldest unread
*PostsApi* | [**get_posts_by_ids**](docs/PostsApi.md#get_posts_by_ids)<br/>**POST** /posts/ids<br/>Get posts by a list of ids
*PostsApi* | [**get_posts_for_channel**](docs/PostsApi.md#get_posts_for_channel)<br/>**GET** /channels/{channel_id}/posts<br/>Get posts for a channel
*PostsApi* | [**patch_post**](docs/PostsApi.md#patch_post)<br/>**PUT** /posts/{post_id}/patch<br/>Patch a post
*PostsApi* | [**pin_post**](docs/PostsApi.md#pin_post)<br/>**POST** /posts/{post_id}/pin<br/>Pin a post to the channel
*PostsApi* | [**search_posts**](docs/PostsApi.md#search_posts)<br/>**POST** /teams/{team_id}/posts/search<br/>Search for team posts
*PostsApi* | [**set_post_reminder**](docs/PostsApi.md#set_post_reminder)<br/>**POST** /users/{user_id}/posts/{post_id}/reminder<br/>Set a post reminder
*PostsApi* | [**set_post_unread**](docs/PostsApi.md#set_post_unread)<br/>**POST** /users/{user_id}/posts/{post_id}/set_unread<br/>Mark as unread from a post.
*PostsApi* | [**unpin_post**](docs/PostsApi.md#unpin_post)<br/>**POST** /posts/{post_id}/unpin<br/>Unpin a post to the channel
*PostsApi* | [**update_post**](docs/PostsApi.md#update_post)<br/>**PUT** /posts/{post_id}<br/>Update a post
*PreferencesApi* | [**delete_preferences**](docs/PreferencesApi.md#delete_preferences)<br/>**POST** /users/{user_id}/preferences/delete<br/>Delete user&#39;s preferences
*PreferencesApi* | [**get_preferences**](docs/PreferencesApi.md#get_preferences)<br/>**GET** /users/{user_id}/preferences<br/>Get the user&#39;s preferences
*PreferencesApi* | [**get_preferences_by_category**](docs/PreferencesApi.md#get_preferences_by_category)<br/>**GET** /users/{user_id}/preferences/{category}<br/>List a user&#39;s preferences by category
*PreferencesApi* | [**get_preferences_by_category_by_name**](docs/PreferencesApi.md#get_preferences_by_category_by_name)<br/>**GET** /users/{user_id}/preferences/{category}/name/{preference_name}<br/>Get a specific user preference
*PreferencesApi* | [**update_preferences**](docs/PreferencesApi.md#update_preferences)<br/>**PUT** /users/{user_id}/preferences<br/>Save the user&#39;s preferences
*ReactionsApi* | [**delete_reaction**](docs/ReactionsApi.md#delete_reaction)<br/>**DELETE** /users/{user_id}/posts/{post_id}/reactions/{emoji_name}<br/>Remove a reaction from a post
*ReactionsApi* | [**get_bulk_reactions**](docs/ReactionsApi.md#get_bulk_reactions)<br/>**POST** /posts/ids/reactions<br/>Bulk get the reaction for posts
*ReactionsApi* | [**get_reactions**](docs/ReactionsApi.md#get_reactions)<br/>**GET** /posts/{post_id}/reactions<br/>Get a list of reactions to a post
*ReactionsApi* | [**save_reaction**](docs/ReactionsApi.md#save_reaction)<br/>**POST** /reactions<br/>Create a reaction
*RolesApi* | [**get_all_roles**](docs/RolesApi.md#get_all_roles)<br/>**GET** /roles<br/>Get a list of all the roles
*RolesApi* | [**get_role**](docs/RolesApi.md#get_role)<br/>**GET** /roles/{role_id}<br/>Get a role
*RolesApi* | [**get_role_by_name**](docs/RolesApi.md#get_role_by_name)<br/>**GET** /roles/name/{role_name}<br/>Get a role
*RolesApi* | [**get_roles_by_names**](docs/RolesApi.md#get_roles_by_names)<br/>**POST** /roles/names<br/>Get a list of roles by name
*RolesApi* | [**patch_role**](docs/RolesApi.md#patch_role)<br/>**PUT** /roles/{role_id}/patch<br/>Patch a role
*RootApi* | [**acknowledge_notification**](docs/RootApi.md#acknowledge_notification)<br/>**POST** /notifications/ack<br/>Acknowledge receiving of a notification
*SAMLApi* | [**delete_saml_idp_certificate**](docs/SAMLApi.md#delete_saml_idp_certificate)<br/>**DELETE** /saml/certificate/idp<br/>Remove IDP certificate
*SAMLApi* | [**delete_saml_private_certificate**](docs/SAMLApi.md#delete_saml_private_certificate)<br/>**DELETE** /saml/certificate/private<br/>Remove private key
*SAMLApi* | [**delete_saml_public_certificate**](docs/SAMLApi.md#delete_saml_public_certificate)<br/>**DELETE** /saml/certificate/public<br/>Remove public certificate
*SAMLApi* | [**get_saml_certificate_status**](docs/SAMLApi.md#get_saml_certificate_status)<br/>**GET** /saml/certificate/status<br/>Get certificate status
*SAMLApi* | [**get_saml_metadata**](docs/SAMLApi.md#get_saml_metadata)<br/>**GET** /saml/metadata<br/>Get metadata
*SAMLApi* | [**get_saml_metadata_from_idp**](docs/SAMLApi.md#get_saml_metadata_from_idp)<br/>**POST** /saml/metadatafromidp<br/>Get metadata from Identity Provider
*SAMLApi* | [**migrate_auth_to_saml**](docs/SAMLApi.md#migrate_auth_to_saml)<br/>**POST** /users/migrate_auth/saml<br/>Migrate user accounts authentication type to SAML.
*SAMLApi* | [**reset_saml_auth_data_to_email**](docs/SAMLApi.md#reset_saml_auth_data_to_email)<br/>**POST** /saml/reset_auth_data<br/>Reset AuthData to Email
*SAMLApi* | [**upload_saml_idp_certificate**](docs/SAMLApi.md#upload_saml_idp_certificate)<br/>**POST** /saml/certificate/idp<br/>Upload IDP certificate
*SAMLApi* | [**upload_saml_private_certificate**](docs/SAMLApi.md#upload_saml_private_certificate)<br/>**POST** /saml/certificate/private<br/>Upload private key
*SAMLApi* | [**upload_saml_public_certificate**](docs/SAMLApi.md#upload_saml_public_certificate)<br/>**POST** /saml/certificate/public<br/>Upload public certificate
*SchemesApi* | [**create_scheme**](docs/SchemesApi.md#create_scheme)<br/>**POST** /schemes<br/>Create a scheme
*SchemesApi* | [**delete_scheme**](docs/SchemesApi.md#delete_scheme)<br/>**DELETE** /schemes/{scheme_id}<br/>Delete a scheme
*SchemesApi* | [**get_channels_for_scheme**](docs/SchemesApi.md#get_channels_for_scheme)<br/>**GET** /schemes/{scheme_id}/channels<br/>Get a page of channels which use this scheme.
*SchemesApi* | [**get_scheme**](docs/SchemesApi.md#get_scheme)<br/>**GET** /schemes/{scheme_id}<br/>Get a scheme
*SchemesApi* | [**get_schemes**](docs/SchemesApi.md#get_schemes)<br/>**GET** /schemes<br/>Get the schemes.
*SchemesApi* | [**get_teams_for_scheme**](docs/SchemesApi.md#get_teams_for_scheme)<br/>**GET** /schemes/{scheme_id}/teams<br/>Get a page of teams which use this scheme.
*SchemesApi* | [**patch_scheme**](docs/SchemesApi.md#patch_scheme)<br/>**PUT** /schemes/{scheme_id}/patch<br/>Patch a scheme
*SearchApi* | [**search_files**](docs/SearchApi.md#search_files)<br/>**POST** /teams/{team_id}/files/search<br/>Search files in a team
*SharedChannelsApi* | [**get_all_shared_channels**](docs/SharedChannelsApi.md#get_all_shared_channels)<br/>**GET** /sharedchannels/{team_id}<br/>Get all shared channels for team.
*SharedChannelsApi* | [**get_remote_cluster_info**](docs/SharedChannelsApi.md#get_remote_cluster_info)<br/>**GET** /sharedchannels/remote_info/{remote_id}<br/>Get remote cluster info by ID for user.
*StatusApi* | [**get_user_status**](docs/StatusApi.md#get_user_status)<br/>**GET** /users/{user_id}/status<br/>Get user status
*StatusApi* | [**get_users_statuses_by_ids**](docs/StatusApi.md#get_users_statuses_by_ids)<br/>**POST** /users/status/ids<br/>Get user statuses by id
*StatusApi* | [**post_user_recent_custom_status_delete**](docs/StatusApi.md#post_user_recent_custom_status_delete)<br/>**POST** /users/{user_id}/status/custom/recent/delete<br/>Delete user&#39;s recent custom status
*StatusApi* | [**remove_recent_custom_status**](docs/StatusApi.md#remove_recent_custom_status)<br/>**DELETE** /users/{user_id}/status/custom/recent<br/>Delete user&#39;s recent custom status
*StatusApi* | [**unset_user_custom_status**](docs/StatusApi.md#unset_user_custom_status)<br/>**DELETE** /users/{user_id}/status/custom<br/>Unsets user custom status
*StatusApi* | [**update_user_custom_status**](docs/StatusApi.md#update_user_custom_status)<br/>**PUT** /users/{user_id}/status/custom<br/>Update user custom status
*StatusApi* | [**update_user_status**](docs/StatusApi.md#update_user_status)<br/>**PUT** /users/{user_id}/status<br/>Update user status
*SystemApi* | [**check_integrity**](docs/SystemApi.md#check_integrity)<br/>**POST** /integrity<br/>Perform a database integrity check
*SystemApi* | [**clear_server_busy**](docs/SystemApi.md#clear_server_busy)<br/>**DELETE** /server_busy<br/>Clears the server busy (high load) flag
*SystemApi* | [**database_recycle**](docs/SystemApi.md#database_recycle)<br/>**POST** /database/recycle<br/>Recycle database connections
*SystemApi* | [**generate_support_packet**](docs/SystemApi.md#generate_support_packet)<br/>**GET** /system/support_packet<br/>Download a zip file which contains helpful and useful information for troubleshooting your mattermost instance.
*SystemApi* | [**get_analytics_old**](docs/SystemApi.md#get_analytics_old)<br/>**GET** /analytics/old<br/>Get analytics
*SystemApi* | [**get_audits**](docs/SystemApi.md#get_audits)<br/>**GET** /audits<br/>Get audits
*SystemApi* | [**get_client_config**](docs/SystemApi.md#get_client_config)<br/>**GET** /config/client<br/>Get client configuration
*SystemApi* | [**get_client_license**](docs/SystemApi.md#get_client_license)<br/>**GET** /license/client<br/>Get client license
*SystemApi* | [**get_config**](docs/SystemApi.md#get_config)<br/>**GET** /config<br/>Get configuration
*SystemApi* | [**get_environment_config**](docs/SystemApi.md#get_environment_config)<br/>**GET** /config/environment<br/>Get configuration made through environment variables
*SystemApi* | [**get_image_by_url**](docs/SystemApi.md#get_image_by_url)<br/>**GET** /image<br/>Get an image by url
*SystemApi* | [**get_logs**](docs/SystemApi.md#get_logs)<br/>**GET** /logs<br/>Get logs
*SystemApi* | [**get_notices**](docs/SystemApi.md#get_notices)<br/>**GET** /system/notices/{teamId}<br/>Get notices for logged in user in specified team
*SystemApi* | [**get_ping**](docs/SystemApi.md#get_ping)<br/>**GET** /system/ping<br/>Check system health
*SystemApi* | [**get_prev_trial_license**](docs/SystemApi.md#get_prev_trial_license)<br/>**GET** /trial-license/prev<br/>Get last trial license used
*SystemApi* | [**get_redirect_location**](docs/SystemApi.md#get_redirect_location)<br/>**GET** /redirect_location<br/>Get redirect location
*SystemApi* | [**get_server_busy_expires**](docs/SystemApi.md#get_server_busy_expires)<br/>**GET** /server_busy<br/>Get server busy expiry time.
*SystemApi* | [**get_supported_timezone**](docs/SystemApi.md#get_supported_timezone)<br/>**GET** /system/timezones<br/>Retrieve a list of supported timezones
*SystemApi* | [**get_warn_metrics_status**](docs/SystemApi.md#get_warn_metrics_status)<br/>**GET** /warn_metrics/status<br/>Get the warn metrics status (enabled or disabled)
*SystemApi* | [**invalidate_caches**](docs/SystemApi.md#invalidate_caches)<br/>**POST** /caches/invalidate<br/>Invalidate all the caches
*SystemApi* | [**mark_notices_viewed**](docs/SystemApi.md#mark_notices_viewed)<br/>**PUT** /system/notices/view<br/>Update notices as &#39;viewed&#39;
*SystemApi* | [**patch_config**](docs/SystemApi.md#patch_config)<br/>**PUT** /config/patch<br/>Patch configuration
*SystemApi* | [**post_log**](docs/SystemApi.md#post_log)<br/>**POST** /logs<br/>Add log message
*SystemApi* | [**reload_config**](docs/SystemApi.md#reload_config)<br/>**POST** /config/reload<br/>Reload configuration
*SystemApi* | [**remove_license_file**](docs/SystemApi.md#remove_license_file)<br/>**DELETE** /license<br/>Remove license file
*SystemApi* | [**request_license_renewal_link**](docs/SystemApi.md#request_license_renewal_link)<br/>**GET** /license/renewal<br/>Request the license renewal link
*SystemApi* | [**request_trial_license**](docs/SystemApi.md#request_trial_license)<br/>**POST** /trial-license<br/>Request and install a trial license for your server
*SystemApi* | [**restart_server**](docs/SystemApi.md#restart_server)<br/>**POST** /restart<br/>Restart the system after an upgrade from Team Edition to Enterprise Edition
*SystemApi* | [**send_trial_license_warn_metric_ack**](docs/SystemApi.md#send_trial_license_warn_metric_ack)<br/>**POST** /warn_metrics/trial-license-ack/{warn_metric_id}<br/>Request trial license and acknowledge a warning of a metric status
*SystemApi* | [**send_warn_metric_ack**](docs/SystemApi.md#send_warn_metric_ack)<br/>**POST** /warn_metrics/ack/{warn_metric_id}<br/>Acknowledge a warning of a metric status
*SystemApi* | [**set_server_busy**](docs/SystemApi.md#set_server_busy)<br/>**POST** /server_busy<br/>Set the server busy (high load) flag
*SystemApi* | [**test_email**](docs/SystemApi.md#test_email)<br/>**POST** /email/test<br/>Send a test email
*SystemApi* | [**test_s3_connection**](docs/SystemApi.md#test_s3_connection)<br/>**POST** /file/s3_test<br/>Test AWS S3 connection
*SystemApi* | [**test_site_u_r_l**](docs/SystemApi.md#test_site_u_r_l)<br/>**POST** /site_url/test<br/>Checks the validity of a Site URL
*SystemApi* | [**update_config**](docs/SystemApi.md#update_config)<br/>**PUT** /config<br/>Update configuration
*SystemApi* | [**update_marketplace_visited_by_admin**](docs/SystemApi.md#update_marketplace_visited_by_admin)<br/>**POST** /plugins/marketplace/first_admin_visit<br/>Stores that the Plugin Marketplace has been visited by at least an admin.
*SystemApi* | [**upgrade_to_enterprise**](docs/SystemApi.md#upgrade_to_enterprise)<br/>**POST** /upgrade_to_enterprise<br/>Executes an inplace upgrade from Team Edition to Enterprise Edition
*SystemApi* | [**upgrade_to_enterprise_status**](docs/SystemApi.md#upgrade_to_enterprise_status)<br/>**GET** /upgrade_to_enterprise/status<br/>Get the current status for the inplace upgrade from Team Edition to Enterprise Edition
*SystemApi* | [**upload_license_file**](docs/SystemApi.md#upload_license_file)<br/>**POST** /license<br/>Upload license file
*TeamsApi* | [**add_team_member**](docs/TeamsApi.md#add_team_member)<br/>**POST** /teams/{team_id}/members<br/>Add user to team
*TeamsApi* | [**add_team_member_from_invite**](docs/TeamsApi.md#add_team_member_from_invite)<br/>**POST** /teams/members/invite<br/>Add user to team from invite
*TeamsApi* | [**add_team_members**](docs/TeamsApi.md#add_team_members)<br/>**POST** /teams/{team_id}/members/batch<br/>Add multiple users to team
*TeamsApi* | [**create_team**](docs/TeamsApi.md#create_team)<br/>**POST** /teams<br/>Create a team
*TeamsApi* | [**get_all_teams**](docs/TeamsApi.md#get_all_teams)<br/>**GET** /teams<br/>Get teams
*TeamsApi* | [**get_team**](docs/TeamsApi.md#get_team)<br/>**GET** /teams/{team_id}<br/>Get a team
*TeamsApi* | [**get_team_by_name**](docs/TeamsApi.md#get_team_by_name)<br/>**GET** /teams/name/{name}<br/>Get a team by name
*TeamsApi* | [**get_team_icon**](docs/TeamsApi.md#get_team_icon)<br/>**GET** /teams/{team_id}/image<br/>Get the team icon
*TeamsApi* | [**get_team_invite_info**](docs/TeamsApi.md#get_team_invite_info)<br/>**GET** /teams/invite/{invite_id}<br/>Get invite info for a team
*TeamsApi* | [**get_team_member**](docs/TeamsApi.md#get_team_member)<br/>**GET** /teams/{team_id}/members/{user_id}<br/>Get a team member
*TeamsApi* | [**get_team_members**](docs/TeamsApi.md#get_team_members)<br/>**GET** /teams/{team_id}/members<br/>Get team members
*TeamsApi* | [**get_team_members_by_ids**](docs/TeamsApi.md#get_team_members_by_ids)<br/>**POST** /teams/{team_id}/members/ids<br/>Get team members by ids
*TeamsApi* | [**get_team_members_for_user**](docs/TeamsApi.md#get_team_members_for_user)<br/>**GET** /users/{user_id}/teams/members<br/>Get team members for a user
*TeamsApi* | [**get_team_stats**](docs/TeamsApi.md#get_team_stats)<br/>**GET** /teams/{team_id}/stats<br/>Get a team stats
*TeamsApi* | [**get_team_unread**](docs/TeamsApi.md#get_team_unread)<br/>**GET** /users/{user_id}/teams/{team_id}/unread<br/>Get unreads for a team
*TeamsApi* | [**get_teams_for_user**](docs/TeamsApi.md#get_teams_for_user)<br/>**GET** /users/{user_id}/teams<br/>Get a user&#39;s teams
*TeamsApi* | [**get_teams_unread_for_user**](docs/TeamsApi.md#get_teams_unread_for_user)<br/>**GET** /users/{user_id}/teams/unread<br/>Get team unreads for a user
*TeamsApi* | [**import_team**](docs/TeamsApi.md#import_team)<br/>**POST** /teams/{team_id}/import<br/>Import a Team from other application
*TeamsApi* | [**invalidate_email_invites**](docs/TeamsApi.md#invalidate_email_invites)<br/>**DELETE** /teams/invites/email<br/>Invalidate active email invitations
*TeamsApi* | [**invite_guests_to_team**](docs/TeamsApi.md#invite_guests_to_team)<br/>**POST** /teams/{team_id}/invite-guests/email<br/>Invite guests to the team by email
*TeamsApi* | [**invite_users_to_team**](docs/TeamsApi.md#invite_users_to_team)<br/>**POST** /teams/{team_id}/invite/email<br/>Invite users to the team by email
*TeamsApi* | [**patch_team**](docs/TeamsApi.md#patch_team)<br/>**PUT** /teams/{team_id}/patch<br/>Patch a team
*TeamsApi* | [**regenerate_team_invite_id**](docs/TeamsApi.md#regenerate_team_invite_id)<br/>**POST** /teams/{team_id}/regenerate_invite_id<br/>Regenerate the Invite ID from a Team
*TeamsApi* | [**remove_team_icon**](docs/TeamsApi.md#remove_team_icon)<br/>**DELETE** /teams/{team_id}/image<br/>Remove the team icon
*TeamsApi* | [**remove_team_member**](docs/TeamsApi.md#remove_team_member)<br/>**DELETE** /teams/{team_id}/members/{user_id}<br/>Remove user from team
*TeamsApi* | [**restore_team**](docs/TeamsApi.md#restore_team)<br/>**POST** /teams/{team_id}/restore<br/>Restore a team
*TeamsApi* | [**search_files**](docs/TeamsApi.md#search_files)<br/>**POST** /teams/{team_id}/files/search<br/>Search files in a team
*TeamsApi* | [**search_teams**](docs/TeamsApi.md#search_teams)<br/>**POST** /teams/search<br/>Search teams
*TeamsApi* | [**set_team_icon**](docs/TeamsApi.md#set_team_icon)<br/>**POST** /teams/{team_id}/image<br/>Sets the team icon
*TeamsApi* | [**soft_delete_team**](docs/TeamsApi.md#soft_delete_team)<br/>**DELETE** /teams/{team_id}<br/>Delete a team
*TeamsApi* | [**team_exists**](docs/TeamsApi.md#team_exists)<br/>**GET** /teams/name/{name}/exists<br/>Check if team exists
*TeamsApi* | [**team_members_minus_group_members**](docs/TeamsApi.md#team_members_minus_group_members)<br/>**GET** /teams/{team_id}/members_minus_group_members<br/>Team members minus group members.
*TeamsApi* | [**update_team**](docs/TeamsApi.md#update_team)<br/>**PUT** /teams/{team_id}<br/>Update a team
*TeamsApi* | [**update_team_member_roles**](docs/TeamsApi.md#update_team_member_roles)<br/>**PUT** /teams/{team_id}/members/{user_id}/roles<br/>Update a team member roles
*TeamsApi* | [**update_team_member_scheme_roles**](docs/TeamsApi.md#update_team_member_scheme_roles)<br/>**PUT** /teams/{team_id}/members/{user_id}/schemeRoles<br/>Update the scheme-derived roles of a team member.
*TeamsApi* | [**update_team_privacy**](docs/TeamsApi.md#update_team_privacy)<br/>**PUT** /teams/{team_id}/privacy<br/>Update teams&#39;s privacy
*TeamsApi* | [**update_team_scheme**](docs/TeamsApi.md#update_team_scheme)<br/>**PUT** /teams/{team_id}/scheme<br/>Set a team&#39;s scheme
*TermsOfServiceApi* | [**create_terms_of_service**](docs/TermsOfServiceApi.md#create_terms_of_service)<br/>**POST** /terms_of_service<br/>Creates a new terms of service
*TermsOfServiceApi* | [**get_terms_of_service**](docs/TermsOfServiceApi.md#get_terms_of_service)<br/>**GET** /terms_of_service<br/>Get latest terms of service
*TermsOfServiceApi* | [**get_user_terms_of_service**](docs/TermsOfServiceApi.md#get_user_terms_of_service)<br/>**GET** /users/{user_id}/terms_of_service<br/>Fetches user&#39;s latest terms of service action if the latest action was for acceptance.
*TermsOfServiceApi* | [**register_terms_of_service_action**](docs/TermsOfServiceApi.md#register_terms_of_service_action)<br/>**POST** /users/{user_id}/terms_of_service<br/>Records user action when they accept or decline custom terms of service
*ThreadsApi* | [**get_thread_mention_counts_by_channel**](docs/ThreadsApi.md#get_thread_mention_counts_by_channel)<br/>**GET** /users/{user_id}/teams/{team_id}/threads/mention_counts<br/>Get all unread mention counts from followed threads, per-channel
*ThreadsApi* | [**get_user_thread**](docs/ThreadsApi.md#get_user_thread)<br/>**GET** /users/{user_id}/teams/{team_id}/threads/{thread_id}<br/>Get a thread followed by the user
*ThreadsApi* | [**get_user_threads**](docs/ThreadsApi.md#get_user_threads)<br/>**GET** /users/{user_id}/teams/{team_id}/threads<br/>Get all threads that user is following
*ThreadsApi* | [**set_thread_unread_by_post_id**](docs/ThreadsApi.md#set_thread_unread_by_post_id)<br/>**PUT** /users/{user_id}/teams/{team_id}/threads/{thread_id}/set_unread/{post_id}<br/>Mark a thread that user is following as unread based on a post id
*ThreadsApi* | [**start_following_thread**](docs/ThreadsApi.md#start_following_thread)<br/>**PUT** /users/{user_id}/teams/{team_id}/threads/{thread_id}/following<br/>Start following a thread
*ThreadsApi* | [**stop_following_thread**](docs/ThreadsApi.md#stop_following_thread)<br/>**DELETE** /users/{user_id}/teams/{team_id}/threads/{thread_id}/following<br/>Stop following a thread
*ThreadsApi* | [**update_thread_read_for_user**](docs/ThreadsApi.md#update_thread_read_for_user)<br/>**PUT** /users/{user_id}/teams/{team_id}/threads/{thread_id}/read/{timestamp}<br/>Mark a thread that user is following read state to the timestamp
*ThreadsApi* | [**update_threads_read_for_user**](docs/ThreadsApi.md#update_threads_read_for_user)<br/>**PUT** /users/{user_id}/teams/{team_id}/threads/read<br/>Mark all threads that user is following as read
*TimelineApi* | [**remove_timeline_event**](docs/TimelineApi.md#remove_timeline_event)<br/>**DELETE** /runs/{id}/timeline/{event-id}/<br/>Remove a timeline event from the playbook run
*UploadsApi* | [**create_upload**](docs/UploadsApi.md#create_upload)<br/>**POST** /uploads<br/>Create an upload
*UploadsApi* | [**get_upload**](docs/UploadsApi.md#get_upload)<br/>**GET** /uploads/{upload_id}<br/>Get an upload session
*UploadsApi* | [**upload_data**](docs/UploadsApi.md#upload_data)<br/>**POST** /uploads/{upload_id}<br/>Perform a file upload
*UsageApi* | [**get_posts_usage**](docs/UsageApi.md#get_posts_usage)<br/>**GET** /usage/posts<br/>Get current usage of posts
*UsageApi* | [**get_storage_usage**](docs/UsageApi.md#get_storage_usage)<br/>**GET** /usage/storage<br/>Get the total file storage usage for the instance in bytes.
*UsersApi* | [**attach_device_id**](docs/UsersApi.md#attach_device_id)<br/>**PUT** /users/sessions/device<br/>Attach mobile device
*UsersApi* | [**autocomplete_users**](docs/UsersApi.md#autocomplete_users)<br/>**GET** /users/autocomplete<br/>Autocomplete users
*UsersApi* | [**check_user_mfa**](docs/UsersApi.md#check_user_mfa)<br/>**POST** /users/mfa<br/>Check MFA
*UsersApi* | [**convert_bot_to_user**](docs/UsersApi.md#convert_bot_to_user)<br/>**POST** /bots/{bot_user_id}/convert_to_user<br/>Convert a bot into a user
*UsersApi* | [**convert_user_to_bot**](docs/UsersApi.md#convert_user_to_bot)<br/>**POST** /users/{user_id}/convert_to_bot<br/>Convert a user into a bot
*UsersApi* | [**create_user**](docs/UsersApi.md#create_user)<br/>**POST** /users<br/>Create a user
*UsersApi* | [**create_user_access_token**](docs/UsersApi.md#create_user_access_token)<br/>**POST** /users/{user_id}/tokens<br/>Create a user access token
*UsersApi* | [**delete_user**](docs/UsersApi.md#delete_user)<br/>**DELETE** /users/{user_id}<br/>Deactivate a user account.
*UsersApi* | [**demote_user_to_guest**](docs/UsersApi.md#demote_user_to_guest)<br/>**POST** /users/{user_id}/demote<br/>Demote a user to a guest
*UsersApi* | [**disable_user_access_token**](docs/UsersApi.md#disable_user_access_token)<br/>**POST** /users/tokens/disable<br/>Disable personal access token
*UsersApi* | [**enable_user_access_token**](docs/UsersApi.md#enable_user_access_token)<br/>**POST** /users/tokens/enable<br/>Enable personal access token
*UsersApi* | [**generate_mfa_secret**](docs/UsersApi.md#generate_mfa_secret)<br/>**POST** /users/{user_id}/mfa/generate<br/>Generate MFA secret
*UsersApi* | [**get_channel_members_with_team_data_for_user**](docs/UsersApi.md#get_channel_members_with_team_data_for_user)<br/>**GET** /users/{user_id}/channel_members<br/>Get all channel members from all teams for a user
*UsersApi* | [**get_default_profile_image**](docs/UsersApi.md#get_default_profile_image)<br/>**GET** /users/{user_id}/image/default<br/>Return user&#39;s default (generated) profile image
*UsersApi* | [**get_known_users**](docs/UsersApi.md#get_known_users)<br/>**GET** /users/known<br/>Get user IDs of known users
*UsersApi* | [**get_profile_image**](docs/UsersApi.md#get_profile_image)<br/>**GET** /users/{user_id}/image<br/>Get user&#39;s profile image
*UsersApi* | [**get_sessions**](docs/UsersApi.md#get_sessions)<br/>**GET** /users/{user_id}/sessions<br/>Get user&#39;s sessions
*UsersApi* | [**get_total_users_stats**](docs/UsersApi.md#get_total_users_stats)<br/>**GET** /users/stats<br/>Get total count of users in the system
*UsersApi* | [**get_total_users_stats_filtered**](docs/UsersApi.md#get_total_users_stats_filtered)<br/>**GET** /users/stats/filtered<br/>Get total count of users in the system matching the specified filters
*UsersApi* | [**get_uploads_for_user**](docs/UsersApi.md#get_uploads_for_user)<br/>**GET** /users/{user_id}/uploads<br/>Get uploads for a user
*UsersApi* | [**get_user**](docs/UsersApi.md#get_user)<br/>**GET** /users/{user_id}<br/>Get a user
*UsersApi* | [**get_user_access_token**](docs/UsersApi.md#get_user_access_token)<br/>**GET** /users/tokens/{token_id}<br/>Get a user access token
*UsersApi* | [**get_user_access_tokens**](docs/UsersApi.md#get_user_access_tokens)<br/>**GET** /users/tokens<br/>Get user access tokens
*UsersApi* | [**get_user_access_tokens_for_user**](docs/UsersApi.md#get_user_access_tokens_for_user)<br/>**GET** /users/{user_id}/tokens<br/>Get user access tokens
*UsersApi* | [**get_user_audits**](docs/UsersApi.md#get_user_audits)<br/>**GET** /users/{user_id}/audits<br/>Get user&#39;s audits
*UsersApi* | [**get_user_by_email**](docs/UsersApi.md#get_user_by_email)<br/>**GET** /users/email/{email}<br/>Get a user by email
*UsersApi* | [**get_user_by_username**](docs/UsersApi.md#get_user_by_username)<br/>**GET** /users/username/{username}<br/>Get a user by username
*UsersApi* | [**get_user_terms_of_service**](docs/UsersApi.md#get_user_terms_of_service)<br/>**GET** /users/{user_id}/terms_of_service<br/>Fetches user&#39;s latest terms of service action if the latest action was for acceptance.
*UsersApi* | [**get_users**](docs/UsersApi.md#get_users)<br/>**GET** /users<br/>Get users
*UsersApi* | [**get_users_by_group_channel_ids**](docs/UsersApi.md#get_users_by_group_channel_ids)<br/>**POST** /users/group_channels<br/>Get users by group channels ids
*UsersApi* | [**get_users_by_ids**](docs/UsersApi.md#get_users_by_ids)<br/>**POST** /users/ids<br/>Get users by ids
*UsersApi* | [**get_users_by_usernames**](docs/UsersApi.md#get_users_by_usernames)<br/>**POST** /users/usernames<br/>Get users by usernames
*UsersApi* | [**login**](docs/UsersApi.md#login)<br/>**POST** /users/login<br/>Login to Mattermost server
*UsersApi* | [**login_by_cws_token**](docs/UsersApi.md#login_by_cws_token)<br/>**POST** /users/login/cws<br/>Auto-Login to Mattermost server using CWS token
*UsersApi* | [**logout**](docs/UsersApi.md#logout)<br/>**POST** /users/logout<br/>Logout from the Mattermost server
*UsersApi* | [**migrate_auth_to_ldap**](docs/UsersApi.md#migrate_auth_to_ldap)<br/>**POST** /users/migrate_auth/ldap<br/>Migrate user accounts authentication type to LDAP.
*UsersApi* | [**migrate_auth_to_saml**](docs/UsersApi.md#migrate_auth_to_saml)<br/>**POST** /users/migrate_auth/saml<br/>Migrate user accounts authentication type to SAML.
*UsersApi* | [**patch_user**](docs/UsersApi.md#patch_user)<br/>**PUT** /users/{user_id}/patch<br/>Patch a user
*UsersApi* | [**permanent_delete_all_users**](docs/UsersApi.md#permanent_delete_all_users)<br/>**DELETE** /users<br/>Permanent delete all users
*UsersApi* | [**promote_guest_to_user**](docs/UsersApi.md#promote_guest_to_user)<br/>**POST** /users/{user_id}/promote<br/>Promote a guest to user
*UsersApi* | [**publish_user_typing**](docs/UsersApi.md#publish_user_typing)<br/>**POST** /users/{user_id}/typing<br/>Publish a user typing websocket event.
*UsersApi* | [**register_terms_of_service_action**](docs/UsersApi.md#register_terms_of_service_action)<br/>**POST** /users/{user_id}/terms_of_service<br/>Records user action when they accept or decline custom terms of service
*UsersApi* | [**reset_password**](docs/UsersApi.md#reset_password)<br/>**POST** /users/password/reset<br/>Reset password
*UsersApi* | [**revoke_all_sessions**](docs/UsersApi.md#revoke_all_sessions)<br/>**POST** /users/{user_id}/sessions/revoke/all<br/>Revoke all active sessions for a user
*UsersApi* | [**revoke_session**](docs/UsersApi.md#revoke_session)<br/>**POST** /users/{user_id}/sessions/revoke<br/>Revoke a user session
*UsersApi* | [**revoke_sessions_from_all_users**](docs/UsersApi.md#revoke_sessions_from_all_users)<br/>**POST** /users/sessions/revoke/all<br/>Revoke all sessions from all users.
*UsersApi* | [**revoke_user_access_token**](docs/UsersApi.md#revoke_user_access_token)<br/>**POST** /users/tokens/revoke<br/>Revoke a user access token
*UsersApi* | [**search_user_access_tokens**](docs/UsersApi.md#search_user_access_tokens)<br/>**POST** /users/tokens/search<br/>Search tokens
*UsersApi* | [**search_users**](docs/UsersApi.md#search_users)<br/>**POST** /users/search<br/>Search users
*UsersApi* | [**send_password_reset_email**](docs/UsersApi.md#send_password_reset_email)<br/>**POST** /users/password/reset/send<br/>Send password reset email
*UsersApi* | [**send_verification_email**](docs/UsersApi.md#send_verification_email)<br/>**POST** /users/email/verify/send<br/>Send verification email
*UsersApi* | [**set_default_profile_image**](docs/UsersApi.md#set_default_profile_image)<br/>**DELETE** /users/{user_id}/image<br/>Delete user&#39;s profile image
*UsersApi* | [**set_profile_image**](docs/UsersApi.md#set_profile_image)<br/>**POST** /users/{user_id}/image<br/>Set user&#39;s profile image
*UsersApi* | [**switch_account_type**](docs/UsersApi.md#switch_account_type)<br/>**POST** /users/login/switch<br/>Switch login method
*UsersApi* | [**update_user**](docs/UsersApi.md#update_user)<br/>**PUT** /users/{user_id}<br/>Update a user
*UsersApi* | [**update_user_active**](docs/UsersApi.md#update_user_active)<br/>**PUT** /users/{user_id}/active<br/>Update user active status
*UsersApi* | [**update_user_auth**](docs/UsersApi.md#update_user_auth)<br/>**PUT** /users/{user_id}/auth<br/>Update a user&#39;s authentication method
*UsersApi* | [**update_user_mfa**](docs/UsersApi.md#update_user_mfa)<br/>**PUT** /users/{user_id}/mfa<br/>Update a user&#39;s MFA
*UsersApi* | [**update_user_password**](docs/UsersApi.md#update_user_password)<br/>**PUT** /users/{user_id}/password<br/>Update a user&#39;s password
*UsersApi* | [**update_user_roles**](docs/UsersApi.md#update_user_roles)<br/>**PUT** /users/{user_id}/roles<br/>Update a user&#39;s roles
*UsersApi* | [**verify_user_email**](docs/UsersApi.md#verify_user_email)<br/>**POST** /users/email/verify<br/>Verify user email
*UsersApi* | [**verify_user_email_without_token**](docs/UsersApi.md#verify_user_email_without_token)<br/>**POST** /users/{user_id}/email/verify/member<br/>Verify user email by ID
*WebhooksApi* | [**create_incoming_webhook**](docs/WebhooksApi.md#create_incoming_webhook)<br/>**POST** /hooks/incoming<br/>Create an incoming webhook
*WebhooksApi* | [**create_outgoing_webhook**](docs/WebhooksApi.md#create_outgoing_webhook)<br/>**POST** /hooks/outgoing<br/>Create an outgoing webhook
*WebhooksApi* | [**delete_incoming_webhook**](docs/WebhooksApi.md#delete_incoming_webhook)<br/>**DELETE** /hooks/incoming/{hook_id}<br/>Delete an incoming webhook
*WebhooksApi* | [**delete_outgoing_webhook**](docs/WebhooksApi.md#delete_outgoing_webhook)<br/>**DELETE** /hooks/outgoing/{hook_id}<br/>Delete an outgoing webhook
*WebhooksApi* | [**get_incoming_webhook**](docs/WebhooksApi.md#get_incoming_webhook)<br/>**GET** /hooks/incoming/{hook_id}<br/>Get an incoming webhook
*WebhooksApi* | [**get_incoming_webhooks**](docs/WebhooksApi.md#get_incoming_webhooks)<br/>**GET** /hooks/incoming<br/>List incoming webhooks
*WebhooksApi* | [**get_outgoing_webhook**](docs/WebhooksApi.md#get_outgoing_webhook)<br/>**GET** /hooks/outgoing/{hook_id}<br/>Get an outgoing webhook
*WebhooksApi* | [**get_outgoing_webhooks**](docs/WebhooksApi.md#get_outgoing_webhooks)<br/>**GET** /hooks/outgoing<br/>List outgoing webhooks
*WebhooksApi* | [**regen_outgoing_hook_token**](docs/WebhooksApi.md#regen_outgoing_hook_token)<br/>**POST** /hooks/outgoing/{hook_id}/regen_token<br/>Regenerate the token for the outgoing webhook.
*WebhooksApi* | [**update_incoming_webhook**](docs/WebhooksApi.md#update_incoming_webhook)<br/>**PUT** /hooks/incoming/{hook_id}<br/>Update an incoming webhook
*WebhooksApi* | [**update_outgoing_webhook**](docs/WebhooksApi.md#update_outgoing_webhook)<br/>**PUT** /hooks/outgoing/{hook_id}<br/>Update an outgoing webhook


## Models

 - [AddChannelMemberRequest](docs/AddChannelMemberRequest.md)
 - [AddChecklistItemRequest](docs/AddChecklistItemRequest.md)
 - [AddGroupMembersRequest](docs/AddGroupMembersRequest.md)
 - [AddOn](docs/AddOn.md)
 - [AddTeamMemberRequest](docs/AddTeamMemberRequest.md)
 - [Address](docs/Address.md)
 - [AppError](docs/AppError.md)
 - [AttachDeviceIdRequest](docs/AttachDeviceIdRequest.md)
 - [Audit](docs/Audit.md)
 - [AutocompleteSuggestion](docs/AutocompleteSuggestion.md)
 - [BoardsLimits](docs/BoardsLimits.md)
 - [Bot](docs/Bot.md)
 - [ChangeOwnerRequest](docs/ChangeOwnerRequest.md)
 - [Channel](docs/Channel.md)
 - [ChannelData](docs/ChannelData.md)
 - [ChannelMember](docs/ChannelMember.md)
 - [ChannelMemberCountByGroup](docs/ChannelMemberCountByGroup.md)
 - [ChannelMemberWithTeamData](docs/ChannelMemberWithTeamData.md)
 - [ChannelMemberWithTeamDataAllOf](docs/ChannelMemberWithTeamDataAllOf.md)
 - [ChannelModeratedRole](docs/ChannelModeratedRole.md)
 - [ChannelModeratedRoles](docs/ChannelModeratedRoles.md)
 - [ChannelModeratedRolesPatch](docs/ChannelModeratedRolesPatch.md)
 - [ChannelModeration](docs/ChannelModeration.md)
 - [ChannelModerationPatch](docs/ChannelModerationPatch.md)
 - [ChannelNotifyProps](docs/ChannelNotifyProps.md)
 - [ChannelStats](docs/ChannelStats.md)
 - [ChannelUnread](docs/ChannelUnread.md)
 - [ChannelUnreadAt](docs/ChannelUnreadAt.md)
 - [ChannelWithTeamData](docs/ChannelWithTeamData.md)
 - [ChannelWithTeamDataAllOf](docs/ChannelWithTeamDataAllOf.md)
 - [CheckUserMfa200Response](docs/CheckUserMfa200Response.md)
 - [CheckUserMfaRequest](docs/CheckUserMfaRequest.md)
 - [Checklist](docs/Checklist.md)
 - [ChecklistItem](docs/ChecklistItem.md)
 - [CloudCustomer](docs/CloudCustomer.md)
 - [ClusterInfo](docs/ClusterInfo.md)
 - [Command](docs/Command.md)
 - [CommandResponse](docs/CommandResponse.md)
 - [Compliance](docs/Compliance.md)
 - [Config](docs/Config.md)
 - [ConfigAnalyticsSettings](docs/ConfigAnalyticsSettings.md)
 - [ConfigClusterSettings](docs/ConfigClusterSettings.md)
 - [ConfigComplianceSettings](docs/ConfigComplianceSettings.md)
 - [ConfigEmailSettings](docs/ConfigEmailSettings.md)
 - [ConfigFileSettings](docs/ConfigFileSettings.md)
 - [ConfigGitLabSettings](docs/ConfigGitLabSettings.md)
 - [ConfigLdapSettings](docs/ConfigLdapSettings.md)
 - [ConfigLocalizationSettings](docs/ConfigLocalizationSettings.md)
 - [ConfigLogSettings](docs/ConfigLogSettings.md)
 - [ConfigMetricsSettings](docs/ConfigMetricsSettings.md)
 - [ConfigNativeAppSettings](docs/ConfigNativeAppSettings.md)
 - [ConfigPasswordSettings](docs/ConfigPasswordSettings.md)
 - [ConfigPrivacySettings](docs/ConfigPrivacySettings.md)
 - [ConfigRateLimitSettings](docs/ConfigRateLimitSettings.md)
 - [ConfigSamlSettings](docs/ConfigSamlSettings.md)
 - [ConfigServiceSettings](docs/ConfigServiceSettings.md)
 - [ConfigSqlSettings](docs/ConfigSqlSettings.md)
 - [ConfigSupportSettings](docs/ConfigSupportSettings.md)
 - [ConfigTeamSettings](docs/ConfigTeamSettings.md)
 - [ConvertBotToUserRequest](docs/ConvertBotToUserRequest.md)
 - [CreateBotRequest](docs/CreateBotRequest.md)
 - [CreateChannelRequest](docs/CreateChannelRequest.md)
 - [CreateCommandRequest](docs/CreateCommandRequest.md)
 - [CreateGroupRequest](docs/CreateGroupRequest.md)
 - [CreateGroupRequestGroup](docs/CreateGroupRequestGroup.md)
 - [CreateIncomingWebhookRequest](docs/CreateIncomingWebhookRequest.md)
 - [CreateJobRequest](docs/CreateJobRequest.md)
 - [CreateOAuthAppRequest](docs/CreateOAuthAppRequest.md)
 - [CreateOutgoingWebhookRequest](docs/CreateOutgoingWebhookRequest.md)
 - [CreatePlaybookRunFromDialogRequest](docs/CreatePlaybookRunFromDialogRequest.md)
 - [CreatePlaybookRunFromDialogRequestSubmission](docs/CreatePlaybookRunFromDialogRequestSubmission.md)
 - [CreatePlaybookRunFromPostRequest](docs/CreatePlaybookRunFromPostRequest.md)
 - [CreatePostEphemeralRequest](docs/CreatePostEphemeralRequest.md)
 - [CreatePostEphemeralRequestPost](docs/CreatePostEphemeralRequestPost.md)
 - [CreatePostRequest](docs/CreatePostRequest.md)
 - [CreateSchemeRequest](docs/CreateSchemeRequest.md)
 - [CreateTeamRequest](docs/CreateTeamRequest.md)
 - [CreateUploadRequest](docs/CreateUploadRequest.md)
 - [CreateUserAccessTokenRequest](docs/CreateUserAccessTokenRequest.md)
 - [CreateUserRequest](docs/CreateUserRequest.md)
 - [DataRetentionPolicy](docs/DataRetentionPolicy.md)
 - [DataRetentionPolicyAllOf](docs/DataRetentionPolicyAllOf.md)
 - [DataRetentionPolicyCreate](docs/DataRetentionPolicyCreate.md)
 - [DataRetentionPolicyForChannel](docs/DataRetentionPolicyForChannel.md)
 - [DataRetentionPolicyForTeam](docs/DataRetentionPolicyForTeam.md)
 - [DataRetentionPolicyWithTeamAndChannelCounts](docs/DataRetentionPolicyWithTeamAndChannelCounts.md)
 - [DataRetentionPolicyWithTeamAndChannelCountsAllOf](docs/DataRetentionPolicyWithTeamAndChannelCountsAllOf.md)
 - [DataRetentionPolicyWithTeamAndChannelIds](docs/DataRetentionPolicyWithTeamAndChannelIds.md)
 - [DataRetentionPolicyWithTeamAndChannelIdsAllOf](docs/DataRetentionPolicyWithTeamAndChannelIdsAllOf.md)
 - [DataRetentionPolicyWithoutId](docs/DataRetentionPolicyWithoutId.md)
 - [DeleteGroupMembersRequest](docs/DeleteGroupMembersRequest.md)
 - [DisableUserAccessTokenRequest](docs/DisableUserAccessTokenRequest.md)
 - [Emoji](docs/Emoji.md)
 - [EnableUserAccessTokenRequest](docs/EnableUserAccessTokenRequest.md)
 - [EnvironmentConfig](docs/EnvironmentConfig.md)
 - [EnvironmentConfigAnalyticsSettings](docs/EnvironmentConfigAnalyticsSettings.md)
 - [EnvironmentConfigClusterSettings](docs/EnvironmentConfigClusterSettings.md)
 - [EnvironmentConfigComplianceSettings](docs/EnvironmentConfigComplianceSettings.md)
 - [EnvironmentConfigEmailSettings](docs/EnvironmentConfigEmailSettings.md)
 - [EnvironmentConfigFileSettings](docs/EnvironmentConfigFileSettings.md)
 - [EnvironmentConfigGitLabSettings](docs/EnvironmentConfigGitLabSettings.md)
 - [EnvironmentConfigLdapSettings](docs/EnvironmentConfigLdapSettings.md)
 - [EnvironmentConfigLocalizationSettings](docs/EnvironmentConfigLocalizationSettings.md)
 - [EnvironmentConfigLogSettings](docs/EnvironmentConfigLogSettings.md)
 - [EnvironmentConfigMetricsSettings](docs/EnvironmentConfigMetricsSettings.md)
 - [EnvironmentConfigNativeAppSettings](docs/EnvironmentConfigNativeAppSettings.md)
 - [EnvironmentConfigPasswordSettings](docs/EnvironmentConfigPasswordSettings.md)
 - [EnvironmentConfigRateLimitSettings](docs/EnvironmentConfigRateLimitSettings.md)
 - [EnvironmentConfigSamlSettings](docs/EnvironmentConfigSamlSettings.md)
 - [EnvironmentConfigServiceSettings](docs/EnvironmentConfigServiceSettings.md)
 - [EnvironmentConfigSqlSettings](docs/EnvironmentConfigSqlSettings.md)
 - [EnvironmentConfigSupportSettings](docs/EnvironmentConfigSupportSettings.md)
 - [EnvironmentConfigTeamSettings](docs/EnvironmentConfigTeamSettings.md)
 - [Error](docs/Error.md)
 - [ExecuteCommandRequest](docs/ExecuteCommandRequest.md)
 - [FileInfo](docs/FileInfo.md)
 - [FileInfoList](docs/FileInfoList.md)
 - [FilesLimits](docs/FilesLimits.md)
 - [GenerateMfaSecret200Response](docs/GenerateMfaSecret200Response.md)
 - [GetChecklistAutocomplete200ResponseInner](docs/GetChecklistAutocomplete200ResponseInner.md)
 - [GetDataRetentionPoliciesCount200Response](docs/GetDataRetentionPoliciesCount200Response.md)
 - [GetFileLink200Response](docs/GetFileLink200Response.md)
 - [GetGroupStats200Response](docs/GetGroupStats200Response.md)
 - [GetGroupUsers200Response](docs/GetGroupUsers200Response.md)
 - [GetPlugins200Response](docs/GetPlugins200Response.md)
 - [GetRedirectLocation200Response](docs/GetRedirectLocation200Response.md)
 - [GetSamlMetadataFromIdpRequest](docs/GetSamlMetadataFromIdpRequest.md)
 - [GetTeamInviteInfo200Response](docs/GetTeamInviteInfo200Response.md)
 - [GetUsersByGroupChannelIds200Response](docs/GetUsersByGroupChannelIds200Response.md)
 - [GlobalDataRetentionPolicy](docs/GlobalDataRetentionPolicy.md)
 - [Group](docs/Group.md)
 - [GroupSyncableChannel](docs/GroupSyncableChannel.md)
 - [GroupSyncableChannels](docs/GroupSyncableChannels.md)
 - [GroupSyncableTeam](docs/GroupSyncableTeam.md)
 - [GroupSyncableTeams](docs/GroupSyncableTeams.md)
 - [GroupWithSchemeAdmin](docs/GroupWithSchemeAdmin.md)
 - [ImportTeam200Response](docs/ImportTeam200Response.md)
 - [IncomingWebhook](docs/IncomingWebhook.md)
 - [InsightUserInformation](docs/InsightUserInformation.md)
 - [InstallMarketplacePluginRequest](docs/InstallMarketplacePluginRequest.md)
 - [IntegrationsLimits](docs/IntegrationsLimits.md)
 - [IntegrityCheckResult](docs/IntegrityCheckResult.md)
 - [InviteGuestsToTeamRequest](docs/InviteGuestsToTeamRequest.md)
 - [Invoice](docs/Invoice.md)
 - [InvoiceLineItem](docs/InvoiceLineItem.md)
 - [ItemRenameRequest](docs/ItemRenameRequest.md)
 - [ItemSetAssigneeRequest](docs/ItemSetAssigneeRequest.md)
 - [ItemSetStateRequest](docs/ItemSetStateRequest.md)
 - [Job](docs/Job.md)
 - [LDAPGroup](docs/LDAPGroup.md)
 - [LDAPGroupsPaged](docs/LDAPGroupsPaged.md)
 - [LicenseRenewalLink](docs/LicenseRenewalLink.md)
 - [LoginByCwsTokenRequest](docs/LoginByCwsTokenRequest.md)
 - [LoginRequest](docs/LoginRequest.md)
 - [MarketplacePlugin](docs/MarketplacePlugin.md)
 - [MessagesLimits](docs/MessagesLimits.md)
 - [MigrateAuthToLdapRequest](docs/MigrateAuthToLdapRequest.md)
 - [MigrateAuthToSamlRequest](docs/MigrateAuthToSamlRequest.md)
 - [MigrateIdLdapRequest](docs/MigrateIdLdapRequest.md)
 - [MoveChannelRequest](docs/MoveChannelRequest.md)
 - [MoveCommandRequest](docs/MoveCommandRequest.md)
 - [NewTeamMember](docs/NewTeamMember.md)
 - [NewTeamMembersList](docs/NewTeamMembersList.md)
 - [NextStageDialogRequest](docs/NextStageDialogRequest.md)
 - [Notice](docs/Notice.md)
 - [OAuthApp](docs/OAuthApp.md)
 - [OpenGraph](docs/OpenGraph.md)
 - [OpenGraphArticle](docs/OpenGraphArticle.md)
 - [OpenGraphArticleAuthorsInner](docs/OpenGraphArticleAuthorsInner.md)
 - [OpenGraphAudiosInner](docs/OpenGraphAudiosInner.md)
 - [OpenGraphBook](docs/OpenGraphBook.md)
 - [OpenGraphImagesInner](docs/OpenGraphImagesInner.md)
 - [OpenGraphRequest](docs/OpenGraphRequest.md)
 - [OpenGraphVideosInner](docs/OpenGraphVideosInner.md)
 - [OpenInteractiveDialogRequest](docs/OpenInteractiveDialogRequest.md)
 - [OpenInteractiveDialogRequestDialog](docs/OpenInteractiveDialogRequestDialog.md)
 - [OrderedSidebarCategories](docs/OrderedSidebarCategories.md)
 - [OrphanedRecord](docs/OrphanedRecord.md)
 - [OutgoingWebhook](docs/OutgoingWebhook.md)
 - [OwnerInfo](docs/OwnerInfo.md)
 - [PatchChannelRequest](docs/PatchChannelRequest.md)
 - [PatchGroupRequest](docs/PatchGroupRequest.md)
 - [PatchGroupSyncableForTeamRequest](docs/PatchGroupSyncableForTeamRequest.md)
 - [PatchPostRequest](docs/PatchPostRequest.md)
 - [PatchRoleRequest](docs/PatchRoleRequest.md)
 - [PatchSchemeRequest](docs/PatchSchemeRequest.md)
 - [PatchTeamRequest](docs/PatchTeamRequest.md)
 - [PatchUserRequest](docs/PatchUserRequest.md)
 - [PaymentMethod](docs/PaymentMethod.md)
 - [PaymentSetupIntent](docs/PaymentSetupIntent.md)
 - [Playbook](docs/Playbook.md)
 - [PlaybookAutofollows](docs/PlaybookAutofollows.md)
 - [PlaybookList](docs/PlaybookList.md)
 - [PlaybookRun](docs/PlaybookRun.md)
 - [PlaybookRunList](docs/PlaybookRunList.md)
 - [PlaybookRunMetadata](docs/PlaybookRunMetadata.md)
 - [PluginManifest](docs/PluginManifest.md)
 - [PluginManifestBackend](docs/PluginManifestBackend.md)
 - [PluginManifestServer](docs/PluginManifestServer.md)
 - [PluginManifestServerExecutables](docs/PluginManifestServerExecutables.md)
 - [PluginManifestWebapp](docs/PluginManifestWebapp.md)
 - [PluginStatus](docs/PluginStatus.md)
 - [Post](docs/Post.md)
 - [PostList](docs/PostList.md)
 - [PostListWithSearchMatches](docs/PostListWithSearchMatches.md)
 - [PostLogRequest](docs/PostLogRequest.md)
 - [PostMetadata](docs/PostMetadata.md)
 - [PostMetadataEmbedsInner](docs/PostMetadataEmbedsInner.md)
 - [PostMetadataImagesInner](docs/PostMetadataImagesInner.md)
 - [PostsUsage](docs/PostsUsage.md)
 - [Preference](docs/Preference.md)
 - [Product](docs/Product.md)
 - [ProductLimits](docs/ProductLimits.md)
 - [PublishUserTypingRequest](docs/PublishUserTypingRequest.md)
 - [PushNotification](docs/PushNotification.md)
 - [Reaction](docs/Reaction.md)
 - [RegenCommandToken200Response](docs/RegenCommandToken200Response.md)
 - [RegisterTermsOfServiceActionRequest](docs/RegisterTermsOfServiceActionRequest.md)
 - [RelationalIntegrityCheckData](docs/RelationalIntegrityCheckData.md)
 - [RemoteClusterInfo](docs/RemoteClusterInfo.md)
 - [RemoveRecentCustomStatusRequest](docs/RemoveRecentCustomStatusRequest.md)
 - [ReoderChecklistItemRequest](docs/ReoderChecklistItemRequest.md)
 - [RequestTrialLicenseRequest](docs/RequestTrialLicenseRequest.md)
 - [ResetPasswordRequest](docs/ResetPasswordRequest.md)
 - [ResetSamlAuthDataToEmail200Response](docs/ResetSamlAuthDataToEmail200Response.md)
 - [ResetSamlAuthDataToEmailRequest](docs/ResetSamlAuthDataToEmailRequest.md)
 - [RetentionPolicyForChannelList](docs/RetentionPolicyForChannelList.md)
 - [RetentionPolicyForTeamList](docs/RetentionPolicyForTeamList.md)
 - [RevokeSessionRequest](docs/RevokeSessionRequest.md)
 - [RevokeUserAccessTokenRequest](docs/RevokeUserAccessTokenRequest.md)
 - [Role](docs/Role.md)
 - [SamlCertificateStatus](docs/SamlCertificateStatus.md)
 - [Scheme](docs/Scheme.md)
 - [SearchAllChannels200Response](docs/SearchAllChannels200Response.md)
 - [SearchAllChannelsRequest](docs/SearchAllChannelsRequest.md)
 - [SearchArchivedChannelsRequest](docs/SearchArchivedChannelsRequest.md)
 - [SearchChannelsForRetentionPolicyRequest](docs/SearchChannelsForRetentionPolicyRequest.md)
 - [SearchChannelsRequest](docs/SearchChannelsRequest.md)
 - [SearchEmojiRequest](docs/SearchEmojiRequest.md)
 - [SearchGroupChannelsRequest](docs/SearchGroupChannelsRequest.md)
 - [SearchPostsRequest](docs/SearchPostsRequest.md)
 - [SearchTeams200Response](docs/SearchTeams200Response.md)
 - [SearchTeamsForRetentionPolicyRequest](docs/SearchTeamsForRetentionPolicyRequest.md)
 - [SearchTeamsRequest](docs/SearchTeamsRequest.md)
 - [SearchUserAccessTokensRequest](docs/SearchUserAccessTokensRequest.md)
 - [SearchUsersRequest](docs/SearchUsersRequest.md)
 - [SendPasswordResetEmailRequest](docs/SendPasswordResetEmailRequest.md)
 - [SendVerificationEmailRequest](docs/SendVerificationEmailRequest.md)
 - [SendWarnMetricAckRequest](docs/SendWarnMetricAckRequest.md)
 - [ServerBusy](docs/ServerBusy.md)
 - [Session](docs/Session.md)
 - [SetPostReminderRequest](docs/SetPostReminderRequest.md)
 - [SharedChannel](docs/SharedChannel.md)
 - [SidebarCategory](docs/SidebarCategory.md)
 - [SidebarCategoryWithChannels](docs/SidebarCategoryWithChannels.md)
 - [SlackAttachment](docs/SlackAttachment.md)
 - [SlackAttachmentField](docs/SlackAttachmentField.md)
 - [Status](docs/Status.md)
 - [StatusOK](docs/StatusOK.md)
 - [StatusRequest](docs/StatusRequest.md)
 - [StorageUsage](docs/StorageUsage.md)
 - [SubmitInteractiveDialogRequest](docs/SubmitInteractiveDialogRequest.md)
 - [Subscription](docs/Subscription.md)
 - [SubscriptionStats](docs/SubscriptionStats.md)
 - [SwitchAccountType200Response](docs/SwitchAccountType200Response.md)
 - [SwitchAccountTypeRequest](docs/SwitchAccountTypeRequest.md)
 - [System](docs/System.md)
 - [SystemStatusResponse](docs/SystemStatusResponse.md)
 - [Team](docs/Team.md)
 - [TeamExists](docs/TeamExists.md)
 - [TeamMap](docs/TeamMap.md)
 - [TeamMember](docs/TeamMember.md)
 - [TeamStats](docs/TeamStats.md)
 - [TeamUnread](docs/TeamUnread.md)
 - [TeamsLimits](docs/TeamsLimits.md)
 - [TermsOfService](docs/TermsOfService.md)
 - [TestSiteURLRequest](docs/TestSiteURLRequest.md)
 - [Timezone](docs/Timezone.md)
 - [TopChannel](docs/TopChannel.md)
 - [TopChannelList](docs/TopChannelList.md)
 - [TopDM](docs/TopDM.md)
 - [TopDMInsightUserInformation](docs/TopDMInsightUserInformation.md)
 - [TopDMInsightUserInformationAllOf](docs/TopDMInsightUserInformationAllOf.md)
 - [TopDMList](docs/TopDMList.md)
 - [TopReaction](docs/TopReaction.md)
 - [TopReactionList](docs/TopReactionList.md)
 - [TopThread](docs/TopThread.md)
 - [TopThreadList](docs/TopThreadList.md)
 - [TriggerIdReturn](docs/TriggerIdReturn.md)
 - [UpdateChannelPrivacyRequest](docs/UpdateChannelPrivacyRequest.md)
 - [UpdateChannelRequest](docs/UpdateChannelRequest.md)
 - [UpdateCloudCustomerRequest](docs/UpdateCloudCustomerRequest.md)
 - [UpdateIncomingWebhookRequest](docs/UpdateIncomingWebhookRequest.md)
 - [UpdateOAuthAppRequest](docs/UpdateOAuthAppRequest.md)
 - [UpdateOutgoingWebhookRequest](docs/UpdateOutgoingWebhookRequest.md)
 - [UpdatePlaybookRunRequest](docs/UpdatePlaybookRunRequest.md)
 - [UpdatePostRequest](docs/UpdatePostRequest.md)
 - [UpdateTeamMemberSchemeRolesRequest](docs/UpdateTeamMemberSchemeRolesRequest.md)
 - [UpdateTeamPrivacyRequest](docs/UpdateTeamPrivacyRequest.md)
 - [UpdateTeamRequest](docs/UpdateTeamRequest.md)
 - [UpdateTeamSchemeRequest](docs/UpdateTeamSchemeRequest.md)
 - [UpdateUserActiveRequest](docs/UpdateUserActiveRequest.md)
 - [UpdateUserCustomStatusRequest](docs/UpdateUserCustomStatusRequest.md)
 - [UpdateUserMfaRequest](docs/UpdateUserMfaRequest.md)
 - [UpdateUserPasswordRequest](docs/UpdateUserPasswordRequest.md)
 - [UpdateUserRequest](docs/UpdateUserRequest.md)
 - [UpdateUserRolesRequest](docs/UpdateUserRolesRequest.md)
 - [UpdateUserStatusRequest](docs/UpdateUserStatusRequest.md)
 - [UpgradeToEnterpriseStatus200Response](docs/UpgradeToEnterpriseStatus200Response.md)
 - [UploadFile201Response](docs/UploadFile201Response.md)
 - [UploadSession](docs/UploadSession.md)
 - [User](docs/User.md)
 - [UserAccessToken](docs/UserAccessToken.md)
 - [UserAccessTokenSanitized](docs/UserAccessTokenSanitized.md)
 - [UserAuthData](docs/UserAuthData.md)
 - [UserAutocomplete](docs/UserAutocomplete.md)
 - [UserAutocompleteInChannel](docs/UserAutocompleteInChannel.md)
 - [UserAutocompleteInTeam](docs/UserAutocompleteInTeam.md)
 - [UserNotifyProps](docs/UserNotifyProps.md)
 - [UserTermsOfService](docs/UserTermsOfService.md)
 - [UserThread](docs/UserThread.md)
 - [UserThreads](docs/UserThreads.md)
 - [UsersStats](docs/UsersStats.md)
 - [VerifyUserEmailRequest](docs/VerifyUserEmailRequest.md)
 - [ViewChannel200Response](docs/ViewChannel200Response.md)
 - [ViewChannelRequest](docs/ViewChannelRequest.md)
 - [WebhookOnCreationPayload](docs/WebhookOnCreationPayload.md)
 - [WebhookOnCreationPayloadAllOf](docs/WebhookOnCreationPayloadAllOf.md)
 - [WebhookOnStatusUpdatePayload](docs/WebhookOnStatusUpdatePayload.md)


## Authorization

## bearerAuth
- **Type**: HTTP basic authentication

Example
```
    using OpenAPI
    using OpenAPI.Clients
    import OpenAPI.Clients: Client, set_header
    client = Client(server_uri)
    set_header(client, "Authorization", "Basic $basic_auth")
    api = MyApi(client)
    result = callApi(api, args...; api_key)
```
## BearerAuth
- **Type**: HTTP basic authentication

Example
```
    using OpenAPI
    using OpenAPI.Clients
    import OpenAPI.Clients: Client, set_header
    client = Client(server_uri)
    set_header(client, "Authorization", "Basic $basic_auth")
    api = MyApi(client)
    result = callApi(api, args...; api_key)
```

## Author

feedback@mattermost.com

